@@ -6,6 +6,7 @@ from dataclasses import replace
 from typing import TYPE_CHECKING, Any, Callable, ClassVar, Optional
 
 from sqlspec.adapters.adbc.driver import AdbcConnection, AdbcDriver
+from sqlspec.adapters.adbc.transformers import AdbcPostgresTransformer
 from sqlspec.config import NoPoolSyncConfig
 from sqlspec.exceptions import ImproperConfigurationError
 from sqlspec.statement.sql import SQLConfig
@@ -69,41 +70,6 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
     - Cloud database integrations
     """
 
-    __slots__ = (
-        "_dialect",
-        "account",
-        "adbc_driver_manager_entrypoint",
-        "authorization_header",
-        "autocommit",
-        "batch_size",
-        "conn_kwargs",
-        "connection_timeout",
-        "database",
-        "dataset_id",
-        "db_kwargs",
-        "default_row_type",
-        "driver_name",
-        "extras",
-        "grpc_options",
-        "isolation_level",
-        "on_connection_create",
-        "password",
-        "pool_instance",
-        "project_id",
-        "query_timeout",
-        "role",
-        "schema",
-        "ssl_ca",
-        "ssl_cert",
-        "ssl_key",
-        "ssl_mode",
-        "statement_config",
-        "token",
-        "uri",
-        "username",
-        "warehouse",
-    )
-
     is_async: ClassVar[bool] = False
     supports_connection_pooling: ClassVar[bool] = False
     driver_type: type[AdbcDriver] = AdbcDriver
@@ -114,7 +80,7 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
     supported_parameter_styles: ClassVar[tuple[str, ...]] = ("qmark",)
     """ADBC parameter styles depend on the underlying driver."""
 
-    preferred_parameter_style: ClassVar[str] = "qmark"
+    default_parameter_style: ClassVar[str] = "qmark"
     """ADBC default parameter style is ? (qmark)."""
 
     def __init__(
@@ -251,7 +217,6 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
         self.statement_config = statement_config or SQLConfig()
         self.default_row_type = default_row_type
         self.on_connection_create = on_connection_create
-        self._dialect: DialectType = None
         super().__init__()
 
     def _resolve_driver_name(self) -> str:
@@ -270,7 +235,6 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
 
         # If explicit driver path is provided, normalize it
         if isinstance(driver_name, str):
-            # Handle convenience aliases
             driver_aliases = {
                 "sqlite": "adbc_driver_sqlite.dbapi.connect",
                 "sqlite3": "adbc_driver_sqlite.dbapi.connect",
@@ -294,7 +258,6 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
 
             resolved_driver = driver_aliases.get(driver_name, driver_name)
 
-            # Ensure it ends with .dbapi.connect
             if not resolved_driver.endswith(".dbapi.connect"):
                 resolved_driver = f"{resolved_driver}.dbapi.connect"
 
@@ -383,7 +346,7 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
         """Get parameter styles based on the underlying driver.
 
         Returns:
-            Tuple of (supported_parameter_styles, preferred_parameter_style)
+            Tuple of (supported_parameter_styles, default_parameter_style)
         """
         try:
             driver_path = self._resolve_driver_name()
@@ -402,7 +365,7 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
 
         except Exception:
             # If we can't determine driver, use defaults
-            return (self.supported_parameter_styles, self.preferred_parameter_style)
+            return (self.supported_parameter_styles, self.default_parameter_style)
         return (("qmark",), "qmark")
 
     def create_connection(self) -> AdbcConnection:
@@ -458,17 +421,30 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
         @contextmanager
         def session_manager() -> "Generator[AdbcDriver, None, None]":
             with self.provide_connection(*args, **kwargs) as connection:
-                # Get parameter styles based on the actual driver
                 supported_styles, preferred_style = self._get_parameter_styles()
 
-                # Create statement config with parameter style info if not already set
                 statement_config = self.statement_config
-                if statement_config.allowed_parameter_styles is None:
-                    statement_config = replace(
-                        statement_config,
-                        allowed_parameter_styles=supported_styles,
-                        target_parameter_style=preferred_style,
-                    )
+                if statement_config is not None:
+                    if statement_config.dialect is None:
+                        statement_config = replace(statement_config, dialect=self._get_dialect())
+
+                    if statement_config.allowed_parameter_styles is None:
+                        statement_config = replace(
+                            statement_config,
+                            allowed_parameter_styles=supported_styles,
+                            default_parameter_style=preferred_style,
+                        )
+
+                    # Add ADBC PostgreSQL transformer if needed
+                    if self._get_dialect() == "postgres":
+                        # Get the default transformers from the pipeline
+                        pipeline = statement_config.get_statement_pipeline()
+                        existing_transformers = list(pipeline.transformers)
+
+                        # Append our transformer to the existing ones
+                        existing_transformers.append(AdbcPostgresTransformer())
+
+                        statement_config = replace(statement_config, transformers=existing_transformers)
 
                 driver = self.driver_type(connection=connection, config=statement_config)
                 yield driver
@@ -492,7 +468,6 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
         # Merge extras parameters
         config.update(self.extras)
 
-        # Process URI based on driver type
         if "driver_name" in config:
             driver_name = config["driver_name"]
 
@@ -526,7 +501,6 @@ class AdbcConfig(NoPoolSyncConfig[AdbcConnection, AdbcDriver]):
                 if isinstance(db_kwargs, dict):
                     config.update(db_kwargs)
 
-            # Remove driver_name from config as it's not a connection parameter
             config.pop("driver_name", None)
 
         return config
