@@ -3,11 +3,12 @@
 import logging
 from collections.abc import AsyncGenerator, Awaitable, Callable
 from contextlib import asynccontextmanager
-from dataclasses import replace
 from typing import TYPE_CHECKING, Any, ClassVar, TypedDict
 
-from asyncpg import Record
+from asyncpg import Connection, Record
 from asyncpg import create_pool as asyncpg_create_pool
+from asyncpg.connection import ConnectionMeta
+from asyncpg.pool import Pool, PoolConnectionProxy, PoolConnectionProxyMeta
 from typing_extensions import NotRequired, Unpack
 
 from sqlspec.adapters.asyncpg.driver import AsyncpgConnection, AsyncpgDriver
@@ -19,9 +20,6 @@ from sqlspec.utils.serializers import from_json, to_json
 if TYPE_CHECKING:
     from asyncio.events import AbstractEventLoop
 
-    from asyncpg.pool import Pool
-    from sqlglot.dialects.dialect import DialectType
-
 
 __all__ = ("CONNECTION_FIELDS", "POOL_FIELDS", "AsyncpgConfig")
 
@@ -108,44 +106,10 @@ POOL_FIELDS = CONNECTION_FIELDS.union(
 class AsyncpgConfig(AsyncDatabaseConfig[AsyncpgConnection, "Pool[Record]", AsyncpgDriver]):
     """Configuration for AsyncPG database connections using TypedDict."""
 
-    __slots__ = (
-        "_dialect",
-        "command_timeout",
-        "connect_timeout",
-        "connection_class",
-        "database",
-        "default_row_type",
-        "direct_tls",
-        "dsn",
-        "extras",
-        "host",
-        "init",
-        "json_deserializer",
-        "json_serializer",
-        "loop",
-        "max_cacheable_statement_size",
-        "max_cached_statement_lifetime",
-        "max_inactive_connection_lifetime",
-        "max_queries",
-        "max_size",
-        "min_size",
-        "passfile",
-        "password",
-        "pool_instance",
-        "port",
-        "record_class",
-        "server_settings",
-        "setup",
-        "ssl",
-        "statement_cache_size",
-        "statement_config",
-        "user",
-    )
-
     driver_type: type[AsyncpgDriver] = AsyncpgDriver
     connection_type: type[AsyncpgConnection] = type(AsyncpgConnection)  # type: ignore[assignment]
     supported_parameter_styles: ClassVar[tuple[str, ...]] = ("numeric",)
-    preferred_parameter_style: ClassVar[str] = "numeric"
+    default_parameter_style: ClassVar[str] = "numeric"
 
     def __init__(self, **kwargs: "Unpack[DriverParameters]") -> None:
         """Initialize AsyncPG configuration."""
@@ -220,11 +184,12 @@ class AsyncpgConfig(AsyncDatabaseConfig[AsyncpgConnection, "Pool[Record]", Async
         self.json_serializer = kwargs.get("json_serializer", to_json)
         self.json_deserializer = kwargs.get("json_deserializer", from_json)
         pool_instance_from_kwargs = kwargs.get("pool_instance")
-        self._dialect: DialectType = None
 
         super().__init__()
 
-        # Set pool_instance after super().__init__() to ensure it's not overridden
+        # Override prepared statements to True for PostgreSQL since it supports them well
+        self.enable_prepared_statements = kwargs.get("enable_prepared_statements", True)  # type: ignore[assignment]
+
         if pool_instance_from_kwargs is not None:
             self.pool_instance = pool_instance_from_kwargs
 
@@ -241,7 +206,6 @@ class AsyncpgConfig(AsyncDatabaseConfig[AsyncpgConnection, "Pool[Record]", Async
             if getattr(self, field, None) is not None and getattr(self, field) is not Empty
         }
 
-        # Add connection-specific extras (not pool-specific ones)
         config.update(self.extras)
 
         return config
@@ -318,15 +282,16 @@ class AsyncpgConfig(AsyncDatabaseConfig[AsyncpgConnection, "Pool[Record]", Async
             An AsyncpgDriver instance.
         """
         async with self.provide_connection(*args, **kwargs) as connection:
-            # Create statement config with parameter style info if not already set
             statement_config = self.statement_config
+            # Inject parameter style info if not already set
             if statement_config is not None and statement_config.allowed_parameter_styles is None:
+                from dataclasses import replace
+
                 statement_config = replace(
                     statement_config,
                     allowed_parameter_styles=self.supported_parameter_styles,
-                    target_parameter_style=self.preferred_parameter_style,
+                    default_parameter_style=self.default_parameter_style,
                 )
-
             yield self.driver_type(connection=connection, config=statement_config)
 
     async def provide_pool(self, *args: Any, **kwargs: Any) -> "Pool[Record]":
@@ -348,27 +313,16 @@ class AsyncpgConfig(AsyncDatabaseConfig[AsyncpgConnection, "Pool[Record]", Async
         Returns:
             Dictionary mapping type names to types.
         """
-        # Get base types from parent
         namespace = super().get_signature_namespace()
-
-        # Add AsyncPG-specific types
-        try:
-            from asyncpg import Connection, Record
-            from asyncpg.connection import ConnectionMeta
-            from asyncpg.pool import Pool, PoolConnectionProxy, PoolConnectionProxyMeta
-
-            namespace.update(
-                {
-                    "Connection": Connection,
-                    "Pool": Pool,
-                    "PoolConnectionProxy": PoolConnectionProxy,
-                    "PoolConnectionProxyMeta": PoolConnectionProxyMeta,
-                    "ConnectionMeta": ConnectionMeta,
-                    "Record": Record,
-                    "AsyncpgConnection": type(AsyncpgConnection),  # The Union type alias
-                }
-            )
-        except ImportError:
-            logger.warning("Failed to import AsyncPG types for signature namespace")
-
+        namespace.update(
+            {
+                "Connection": Connection,
+                "Pool": Pool,
+                "PoolConnectionProxy": PoolConnectionProxy,
+                "PoolConnectionProxyMeta": PoolConnectionProxyMeta,
+                "ConnectionMeta": ConnectionMeta,
+                "Record": Record,
+                "AsyncpgConnection": type(AsyncpgConnection),
+            }
+        )
         return namespace
