@@ -4,7 +4,6 @@ import contextlib
 import logging
 from collections.abc import AsyncGenerator
 from contextlib import asynccontextmanager
-from dataclasses import replace
 from typing import TYPE_CHECKING, Any, ClassVar, Optional, cast
 
 import oracledb
@@ -24,7 +23,6 @@ if TYPE_CHECKING:
 
     from oracledb import AuthMode
     from oracledb.pool import AsyncConnectionPool, ConnectionPool
-    from sqlglot.dialects.dialect import DialectType
 
 
 __all__ = ("CONNECTION_FIELDS", "POOL_FIELDS", "OracleAsyncConfig", "OracleSyncConfig")
@@ -74,43 +72,6 @@ POOL_FIELDS = CONNECTION_FIELDS.union(
 class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "ConnectionPool", OracleSyncDriver]):
     """Configuration for Oracle synchronous database connections with direct field-based configuration."""
 
-    __slots__ = (
-        "_dialect",
-        "config_dir",
-        "default_row_type",
-        "dsn",
-        "edition",
-        "events",
-        "extras",
-        "getmode",
-        "homogeneous",
-        "host",
-        "increment",
-        "max",
-        "max_lifetime_session",
-        "max_sessions_per_shard",
-        "min",
-        "mode",
-        "password",
-        "ping_interval",
-        "pool_instance",
-        "port",
-        "retry_count",
-        "retry_delay",
-        "service_name",
-        "session_callback",
-        "sid",
-        "soda_metadata_cache",
-        "statement_config",
-        "tcp_connect_timeout",
-        "threaded",
-        "timeout",
-        "user",
-        "wait_timeout",
-        "wallet_location",
-        "wallet_password",
-    )
-
     is_async: ClassVar[bool] = False
     supports_connection_pooling: ClassVar[bool] = True
 
@@ -121,7 +82,7 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "ConnectionPool"
     supported_parameter_styles: ClassVar[tuple[str, ...]] = ("named_colon", "positional_colon")
     """OracleDB supports :name (named_colon) and :1 (positional_colon) parameter styles."""
 
-    preferred_parameter_style: ClassVar[str] = "named_colon"
+    default_parameter_style: ClassVar[str] = "named_colon"
     """OracleDB's preferred parameter style is :name (named_colon)."""
 
     def __init__(
@@ -237,8 +198,6 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "ConnectionPool"
         # Store other config
         self.statement_config = statement_config or SQLConfig()
         self.default_row_type = default_row_type
-        self.pool_instance = pool_instance
-        self._dialect: DialectType = None
 
         super().__init__()
 
@@ -293,15 +252,16 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "ConnectionPool"
             An OracleSyncDriver instance.
         """
         with self.provide_connection(*args, **kwargs) as conn:
-            # Create statement config with parameter style info if not already set
             statement_config = self.statement_config
+            # Inject parameter style info if not already set
             if statement_config.allowed_parameter_styles is None:
+                from dataclasses import replace
+
                 statement_config = replace(
                     statement_config,
                     allowed_parameter_styles=self.supported_parameter_styles,
-                    target_parameter_style=self.preferred_parameter_style,
+                    default_parameter_style=self.default_parameter_style,
                 )
-
             driver = self.driver_type(connection=conn, config=statement_config)
             yield driver
 
@@ -315,6 +275,19 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "ConnectionPool"
             self.pool_instance = self.create_pool()
         return self.pool_instance
 
+    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+        """Get the signature namespace for OracleDB types.
+
+        This provides all OracleDB-specific types that Litestar needs to recognize
+        to avoid serialization attempts.
+
+        Returns:
+            Dictionary mapping type names to types.
+        """
+        namespace = super().get_signature_namespace()
+        namespace.update({"OracleSyncConnection": OracleSyncConnection, "OracleAsyncConnection": OracleAsyncConnection})
+        return namespace
+
     @property
     def connection_config_dict(self) -> dict[str, Any]:
         """Return the connection configuration as a dict for Oracle operations.
@@ -355,43 +328,6 @@ class OracleSyncConfig(SyncDatabaseConfig[OracleSyncConnection, "ConnectionPool"
 class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "AsyncConnectionPool", OracleAsyncDriver]):
     """Configuration for Oracle asynchronous database connections with direct field-based configuration."""
 
-    __slots__ = (
-        "_dialect",
-        "config_dir",
-        "default_row_type",
-        "dsn",
-        "edition",
-        "events",
-        "extras",
-        "getmode",
-        "homogeneous",
-        "host",
-        "increment",
-        "max",
-        "max_lifetime_session",
-        "max_sessions_per_shard",
-        "min",
-        "mode",
-        "password",
-        "ping_interval",
-        "pool_instance",
-        "port",
-        "retry_count",
-        "retry_delay",
-        "service_name",
-        "session_callback",
-        "sid",
-        "soda_metadata_cache",
-        "statement_config",
-        "tcp_connect_timeout",
-        "threaded",
-        "timeout",
-        "user",
-        "wait_timeout",
-        "wallet_location",
-        "wallet_password",
-    )
-
     is_async: ClassVar[bool] = True
     supports_connection_pooling: ClassVar[bool] = True
 
@@ -402,7 +338,7 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "AsyncConnect
     supported_parameter_styles: ClassVar[tuple[str, ...]] = ("named_colon", "positional_colon")
     """OracleDB supports :name (named_colon) and :1 (positional_colon) parameter styles."""
 
-    preferred_parameter_style: ClassVar[str] = "named_colon"
+    default_parameter_style: ClassVar[str] = "named_colon"
     """OracleDB's preferred parameter style is :name (named_colon)."""
 
     def __init__(
@@ -518,8 +454,6 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "AsyncConnect
         # Store other config
         self.statement_config = statement_config or SQLConfig()
         self.default_row_type = default_row_type
-        self.pool_instance: Optional[AsyncConnectionPool] = pool_instance
-        self._dialect: DialectType = None
 
         super().__init__()
 
@@ -602,15 +536,16 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "AsyncConnect
             An OracleAsyncDriver instance.
         """
         async with self.provide_connection(*args, **kwargs) as conn:
-            # Create statement config with parameter style info if not already set
             statement_config = self.statement_config
+            # Inject parameter style info if not already set
             if statement_config.allowed_parameter_styles is None:
+                from dataclasses import replace
+
                 statement_config = replace(
                     statement_config,
                     allowed_parameter_styles=self.supported_parameter_styles,
-                    target_parameter_style=self.preferred_parameter_style,
+                    default_parameter_style=self.default_parameter_style,
                 )
-
             driver = self.driver_type(connection=conn, config=statement_config)
             yield driver
 
@@ -623,3 +558,16 @@ class OracleAsyncConfig(AsyncDatabaseConfig[OracleAsyncConnection, "AsyncConnect
         if not self.pool_instance:
             self.pool_instance = await self.create_pool()
         return self.pool_instance
+
+    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+        """Get the signature namespace for OracleDB async types.
+
+        This provides all OracleDB async-specific types that Litestar needs to recognize
+        to avoid serialization attempts.
+
+        Returns:
+            Dictionary mapping type names to types.
+        """
+        namespace = super().get_signature_namespace()
+        namespace.update({"OracleSyncConnection": OracleSyncConnection, "OracleAsyncConnection": OracleAsyncConnection})
+        return namespace
