@@ -3,7 +3,6 @@
 import logging
 from collections.abc import AsyncGenerator
 from contextlib import asynccontextmanager
-from dataclasses import replace
 from typing import TYPE_CHECKING, Any, ClassVar, Optional
 
 from psqlpy import ConnectionPool
@@ -16,7 +15,6 @@ from sqlspec.typing import DictRow, Empty
 if TYPE_CHECKING:
     from collections.abc import Callable
 
-    from sqlglot.dialects.dialect import DialectType
 
 logger = logging.getLogger("sqlspec.adapters.psqlpy")
 
@@ -70,56 +68,6 @@ __all__ = ("CONNECTION_FIELDS", "POOL_FIELDS", "PsqlpyConfig")
 class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyDriver]):
     """Configuration for Psqlpy asynchronous database connections with direct field-based configuration."""
 
-    __slots__ = (
-        "_dialect",
-        "application_name",
-        "ca_file",
-        "channel_binding",
-        "client_encoding",
-        "configure",
-        "conn_recycling_method",
-        "connect_timeout_nanosec",
-        "connect_timeout_sec",
-        "db_name",
-        "default_row_type",
-        "dsn",
-        "extras",
-        "gssdelegation",
-        "gssencmode",
-        "gsslib",
-        "host",
-        "hosts",
-        "keepalives",
-        "keepalives_idle_nanosec",
-        "keepalives_idle_sec",
-        "keepalives_interval_nanosec",
-        "keepalives_interval_sec",
-        "keepalives_retries",
-        "krbsrvname",
-        "load_balance_hosts",
-        "max_db_pool_size",
-        "options",
-        "password",
-        "pool_instance",
-        "port",
-        "ports",
-        "require_auth",
-        "service",
-        "ssl_mode",
-        "sslcert",
-        "sslcompression",
-        "sslcrl",
-        "sslkey",
-        "sslnegotiation",
-        "sslpassword",
-        "sslrootcert",
-        "statement_config",
-        "target_session_attrs",
-        "tcp_user_timeout_nanosec",
-        "tcp_user_timeout_sec",
-        "username",
-    )
-
     is_async: ClassVar[bool] = True
     supports_connection_pooling: ClassVar[bool] = True
 
@@ -129,7 +77,7 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
     supported_parameter_styles: ClassVar[tuple[str, ...]] = ("numeric",)
     """Psqlpy only supports $1, $2, ... (numeric) parameter style."""
 
-    preferred_parameter_style: ClassVar[str] = "numeric"
+    default_parameter_style: ClassVar[str] = "numeric"
     """Psqlpy's native parameter style is $1, $2, ... (numeric)."""
 
     def __init__(
@@ -284,8 +232,6 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
         # Store other config
         self.statement_config = statement_config or SQLConfig()
         self.default_row_type = default_row_type
-        self.pool_instance: Optional[ConnectionPool] = pool_instance
-        self._dialect: DialectType = None
 
         super().__init__()
 
@@ -302,7 +248,6 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
             if getattr(self, field, None) is not None and getattr(self, field) is not Empty
         }
 
-        # Add connection-specific extras (not pool-specific ones)
         config.update(self.extras)
 
         return config
@@ -326,7 +271,7 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
 
         return config
 
-    async def _create_pool(self) -> ConnectionPool:
+    async def _create_pool(self) -> "ConnectionPool":
         """Create the actual async connection pool."""
         logger.info("Creating psqlpy connection pool", extra={"adapter": "psqlpy"})
 
@@ -353,17 +298,15 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
             logger.exception("Failed to close psqlpy connection pool", extra={"adapter": "psqlpy", "error": str(e)})
             raise
 
-    async def create_connection(self) -> PsqlpyConnection:
+    async def create_connection(self) -> "PsqlpyConnection":
         """Create a single async connection (not from pool).
 
         Returns:
             A psqlpy Connection instance.
         """
-        # Ensure pool exists
         if not self.pool_instance:
             self.pool_instance = await self._create_pool()
 
-        # Get connection from pool
         return await self.pool_instance.connection()
 
     @asynccontextmanager
@@ -377,7 +320,6 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
         Yields:
             A psqlpy Connection instance.
         """
-        # Ensure pool exists
         if not self.pool_instance:
             self.pool_instance = await self._create_pool()
 
@@ -396,15 +338,16 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
             A PsqlpyDriver instance.
         """
         async with self.provide_connection(*args, **kwargs) as conn:
-            # Create statement config with parameter style info if not already set
             statement_config = self.statement_config
+            # Inject parameter style info if not already set
             if statement_config.allowed_parameter_styles is None:
+                from dataclasses import replace
+
                 statement_config = replace(
                     statement_config,
                     allowed_parameter_styles=self.supported_parameter_styles,
-                    target_parameter_style=self.preferred_parameter_style,
+                    default_parameter_style=self.default_parameter_style,
                 )
-
             driver = self.driver_type(connection=conn, config=statement_config)
             yield driver
 
@@ -417,3 +360,16 @@ class PsqlpyConfig(AsyncDatabaseConfig[PsqlpyConnection, ConnectionPool, PsqlpyD
         if not self.pool_instance:
             self.pool_instance = await self.create_pool()
         return self.pool_instance
+
+    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+        """Get the signature namespace for Psqlpy types.
+
+        This provides all Psqlpy-specific types that Litestar needs to recognize
+        to avoid serialization attempts.
+
+        Returns:
+            Dictionary mapping type names to types.
+        """
+        namespace = super().get_signature_namespace()
+        namespace.update({"PsqlpyConnection": PsqlpyConnection})
+        return namespace
