@@ -3,7 +3,6 @@
 import contextlib
 import logging
 from contextlib import asynccontextmanager
-from dataclasses import replace
 from typing import TYPE_CHECKING, Any, ClassVar, Optional, cast
 
 from psycopg.rows import dict_row
@@ -23,7 +22,6 @@ if TYPE_CHECKING:
     from collections.abc import AsyncGenerator, Callable, Generator
 
     from psycopg import Connection
-    from sqlglot.dialects.dialect import DialectType
 
 logger = logging.getLogger("sqlspec.adapters.psycopg")
 
@@ -68,39 +66,6 @@ __all__ = ("CONNECTION_FIELDS", "POOL_FIELDS", "PsycopgAsyncConfig", "PsycopgSyn
 class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool, PsycopgSyncDriver]):
     """Configuration for Psycopg synchronous database connections with direct field-based configuration."""
 
-    __slots__ = (
-        "_dialect",
-        "application_name",
-        "autocommit",
-        "configure",
-        "connect_timeout",
-        "conninfo",
-        "dbname",
-        "default_row_type",
-        "extras",
-        "host",
-        "kwargs",
-        "max_idle",
-        "max_lifetime",
-        "max_size",
-        "max_waiting",
-        "min_size",
-        "name",
-        "num_workers",
-        "options",
-        "password",
-        "pool_instance",
-        "port",
-        "reconnect_timeout",
-        "sslcert",
-        "sslkey",
-        "sslmode",
-        "sslrootcert",
-        "statement_config",
-        "timeout",
-        "user",
-    )
-
     is_async: ClassVar[bool] = False
     supports_connection_pooling: ClassVar[bool] = True
 
@@ -111,7 +76,7 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
     supported_parameter_styles: ClassVar[tuple[str, ...]] = ("pyformat_positional", "pyformat_named")
     """Psycopg supports %s (positional) and %(name)s (named) parameter styles."""
 
-    preferred_parameter_style: ClassVar[str] = "pyformat_positional"
+    default_parameter_style: ClassVar[str] = "pyformat_positional"
     """Psycopg's native parameter style is %s (pyformat positional)."""
 
     def __init__(
@@ -211,14 +176,12 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
         self.configure = configure
         self.kwargs = kwargs or {}
 
-        # Handle extras and additional kwargs
         self.extras = extras or {}
         self.extras.update(additional_kwargs)
 
         # Store other config
         self.statement_config = statement_config or SQLConfig()
         self.default_row_type = default_row_type
-        self._dialect: DialectType = None
 
         super().__init__()
 
@@ -240,7 +203,6 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
         if self.kwargs:
             config.update(self.kwargs)
 
-        # Set DictRow as the row factory
         config["row_factory"] = dict_row
 
         return config
@@ -263,7 +225,6 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
         if self.kwargs:
             config.update(self.kwargs)
 
-        # Set DictRow as the row factory
         config["row_factory"] = dict_row
 
         return config
@@ -273,7 +234,6 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
         logger.info("Creating Psycopg connection pool", extra={"adapter": "psycopg"})
 
         try:
-            # Get all config (creates a new dict)
             all_config = self.pool_config_dict.copy()
 
             # Separate pool-specific parameters that ConnectionPool accepts directly
@@ -289,28 +249,27 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
                 "num_workers": all_config.pop("num_workers", 3),
             }
 
-            # Create a configure callback to set row_factory
+            # Capture autocommit setting before configuring the pool
+            autocommit_setting = all_config.get("autocommit")
+
             def configure_connection(conn: "PsycopgSyncConnection") -> None:
-                # Set DictRow as the row factory
                 conn.row_factory = dict_row
+                # Apply autocommit setting if specified
+                if autocommit_setting is not None:
+                    conn.autocommit = autocommit_setting
 
             pool_params["configure"] = all_config.pop("configure", configure_connection)
 
-            # Remove None values from pool_params
             pool_params = {k: v for k, v in pool_params.items() if v is not None}
 
-            # Handle conninfo vs individual connection parameters
             conninfo = all_config.pop("conninfo", None)
             if conninfo:
                 # If conninfo is provided, use it directly
                 # Don't pass kwargs when using conninfo string
                 pool = ConnectionPool(conninfo, open=True, **pool_params)
             else:
-                # Otherwise, pass connection parameters via kwargs
-                # Remove any non-connection parameters
                 # row_factory is already popped out earlier
                 all_config.pop("row_factory", None)
-                # Remove pool-specific settings that may have been left
                 all_config.pop("kwargs", None)
                 pool = ConnectionPool("", kwargs=all_config, open=True, **pool_params)
 
@@ -328,7 +287,6 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
         logger.info("Closing Psycopg connection pool", extra={"adapter": "psycopg"})
 
         try:
-            # Set a flag to prevent __del__ from running cleanup
             # This avoids the "cannot join current thread" error during garbage collection
             if hasattr(self.pool_instance, "_closed"):
                 self.pool_instance._closed = True
@@ -339,7 +297,6 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
             logger.exception("Failed to close Psycopg connection pool", extra={"adapter": "psycopg", "error": str(e)})
             raise
         finally:
-            # Clear the reference to help garbage collection
             self.pool_instance = None
 
     def create_connection(self) -> "PsycopgSyncConnection":
@@ -385,15 +342,16 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
             A PsycopgSyncDriver instance.
         """
         with self.provide_connection(*args, **kwargs) as conn:
-            # Create statement config with parameter style info if not already set
             statement_config = self.statement_config
+            # Inject parameter style info if not already set
             if statement_config.allowed_parameter_styles is None:
+                from dataclasses import replace
+
                 statement_config = replace(
                     statement_config,
                     allowed_parameter_styles=self.supported_parameter_styles,
-                    target_parameter_style=self.preferred_parameter_style,
+                    default_parameter_style=self.default_parameter_style,
                 )
-
             driver = self.driver_type(connection=conn, config=statement_config)
             yield driver
 
@@ -407,43 +365,23 @@ class PsycopgSyncConfig(SyncDatabaseConfig[PsycopgSyncConnection, ConnectionPool
             self.pool_instance = self.create_pool()
         return self.pool_instance
 
+    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+        """Get the signature namespace for Psycopg types.
+
+        This provides all Psycopg-specific types that Litestar needs to recognize
+        to avoid serialization attempts.
+
+        Returns:
+            Dictionary mapping type names to types.
+        """
+        namespace = super().get_signature_namespace()
+        namespace.update({"PsycopgSyncConnection": PsycopgSyncConnection})
+        return namespace
+
 
 class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnectionPool, PsycopgAsyncDriver]):
     """Configuration for Psycopg asynchronous database connections with direct field-based configuration."""
 
-    __slots__ = (
-        "_dialect",
-        "application_name",
-        "autocommit",
-        "configure",
-        "connect_timeout",
-        "conninfo",
-        "dbname",
-        "default_row_type",
-        "extras",
-        "host",
-        "kwargs",
-        "max_idle",
-        "max_lifetime",
-        "max_size",
-        "max_waiting",
-        "min_size",
-        "name",
-        "num_workers",
-        "options",
-        "password",
-        "pool_instance",
-        "port",
-        "reconnect_timeout",
-        "sslcert",
-        "sslkey",
-        "sslmode",
-        "sslrootcert",
-        "statement_config",
-        "timeout",
-        "user",
-    )
-
     is_async: ClassVar[bool] = True
     supports_connection_pooling: ClassVar[bool] = True
 
@@ -455,7 +393,7 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
     supported_parameter_styles: ClassVar[tuple[str, ...]] = ("pyformat_positional", "pyformat_named")
     """Psycopg supports %s (pyformat_positional) and %(name)s (pyformat_named) parameter styles."""
 
-    preferred_parameter_style: ClassVar[str] = "pyformat_positional"
+    default_parameter_style: ClassVar[str] = "pyformat_positional"
     """Psycopg's preferred parameter style is %s (pyformat_positional)."""
 
     def __init__(
@@ -555,14 +493,12 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
         self.configure = configure
         self.kwargs = kwargs or {}
 
-        # Handle extras and additional kwargs
         self.extras = extras or {}
         self.extras.update(additional_kwargs)
 
         # Store other config
         self.statement_config = statement_config or SQLConfig()
         self.default_row_type = default_row_type
-        self._dialect: DialectType = None
 
         super().__init__()
 
@@ -584,7 +520,6 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
         if self.kwargs:
             config.update(self.kwargs)
 
-        # Set DictRow as the row factory
         config["row_factory"] = dict_row
 
         return config
@@ -607,7 +542,6 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
         if self.kwargs:
             config.update(self.kwargs)
 
-        # Set DictRow as the row factory
         config["row_factory"] = dict_row
 
         return config
@@ -615,7 +549,6 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
     async def _create_pool(self) -> "AsyncConnectionPool":
         """Create the actual async connection pool."""
 
-        # Get all config (creates a new dict)
         all_config = self.pool_config_dict.copy()
 
         # Separate pool-specific parameters that AsyncConnectionPool accepts directly
@@ -631,28 +564,27 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
             "num_workers": all_config.pop("num_workers", 3),
         }
 
-        # Create a configure callback to set row_factory
+        # Capture autocommit setting before configuring the pool
+        autocommit_setting = all_config.get("autocommit")
+
         async def configure_connection(conn: "PsycopgAsyncConnection") -> None:
-            # Set DictRow as the row factory
             conn.row_factory = dict_row
+            # Apply autocommit setting if specified (async version requires await)
+            if autocommit_setting is not None:
+                await conn.set_autocommit(autocommit_setting)
 
         pool_params["configure"] = all_config.pop("configure", configure_connection)
 
-        # Remove None values from pool_params
         pool_params = {k: v for k, v in pool_params.items() if v is not None}
 
-        # Handle conninfo vs individual connection parameters
         conninfo = all_config.pop("conninfo", None)
         if conninfo:
             # If conninfo is provided, use it directly
             # Don't pass kwargs when using conninfo string
             pool = AsyncConnectionPool(conninfo, open=False, **pool_params)
         else:
-            # Otherwise, pass connection parameters via kwargs
-            # Remove any non-connection parameters
             # row_factory is already popped out earlier
             all_config.pop("row_factory", None)
-            # Remove pool-specific settings that may have been left
             all_config.pop("kwargs", None)
             pool = AsyncConnectionPool("", kwargs=all_config, open=False, **pool_params)
 
@@ -666,14 +598,12 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
             return
 
         try:
-            # Set a flag to prevent __del__ from running cleanup
             # This avoids the "cannot join current thread" error during garbage collection
             if hasattr(self.pool_instance, "_closed"):
                 self.pool_instance._closed = True
 
             await self.pool_instance.close()
         finally:
-            # Clear the reference to help garbage collection
             self.pool_instance = None
 
     async def create_connection(self) -> "PsycopgAsyncConnection":  # pyright: ignore
@@ -719,15 +649,16 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
             A PsycopgAsyncDriver instance.
         """
         async with self.provide_connection(*args, **kwargs) as conn:
-            # Create statement config with parameter style info if not already set
             statement_config = self.statement_config
+            # Inject parameter style info if not already set
             if statement_config.allowed_parameter_styles is None:
+                from dataclasses import replace
+
                 statement_config = replace(
                     statement_config,
                     allowed_parameter_styles=self.supported_parameter_styles,
-                    target_parameter_style=self.preferred_parameter_style,
+                    default_parameter_style=self.default_parameter_style,
                 )
-
             driver = self.driver_type(connection=conn, config=statement_config)
             yield driver
 
@@ -740,3 +671,16 @@ class PsycopgAsyncConfig(AsyncDatabaseConfig[PsycopgAsyncConnection, AsyncConnec
         if not self.pool_instance:
             self.pool_instance = await self.create_pool()
         return self.pool_instance
+
+    def get_signature_namespace(self) -> "dict[str, type[Any]]":
+        """Get the signature namespace for Psycopg async types.
+
+        This provides all Psycopg async-specific types that Litestar needs to recognize
+        to avoid serialization attempts.
+
+        Returns:
+            Dictionary mapping type names to types.
+        """
+        namespace = super().get_signature_namespace()
+        namespace.update({"PsycopgAsyncConnection": PsycopgAsyncConnection})
+        return namespace
