@@ -4,22 +4,26 @@ import sqlite3
 from collections.abc import Iterator
 from contextlib import contextmanager
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Optional, Union, cast
+from typing import TYPE_CHECKING, Any, Optional, cast
 
 from typing_extensions import TypeAlias
 
 from sqlspec.driver import SyncDriverAdapterProtocol
+from sqlspec.driver.connection import managed_transaction_sync
 from sqlspec.driver.mixins import (
     SQLTranslatorMixin,
+    SyncAdapterCacheMixin,
     SyncPipelinedExecutionMixin,
+    SyncQueryMixin,
     SyncStorageMixin,
     ToSchemaMixin,
     TypeCoercionMixin,
 )
-from sqlspec.statement.parameters import ParameterStyle
-from sqlspec.statement.result import DMLResultDict, ScriptResultDict, SelectResultDict, SQLResult
+from sqlspec.driver.parameters import convert_parameter_sequence
+from sqlspec.statement.parameters import ParameterStyle, ParameterValidator
+from sqlspec.statement.result import SQLResult
 from sqlspec.statement.sql import SQL, SQLConfig
-from sqlspec.typing import DictRow, ModelDTOT, RowT, is_dict_with_field
+from sqlspec.typing import DictRow, RowT
 from sqlspec.utils.logging import get_logger
 from sqlspec.utils.serializers import to_json
 
@@ -35,10 +39,12 @@ SqliteConnection: TypeAlias = sqlite3.Connection
 
 class SqliteDriver(
     SyncDriverAdapterProtocol[SqliteConnection, RowT],
+    SyncAdapterCacheMixin,
     SQLTranslatorMixin,
     TypeCoercionMixin,
     SyncStorageMixin,
     SyncPipelinedExecutionMixin,
+    SyncQueryMixin,
     ToSchemaMixin,
 ):
     """SQLite Sync Driver Adapter with Arrow/Parquet export support.
@@ -47,8 +53,6 @@ class SqliteDriver(
     instrumentation standards following the psycopg pattern.
     """
 
-    __slots__ = ()
-
     dialect: "DialectType" = "sqlite"
     supported_parameter_styles: "tuple[ParameterStyle, ...]" = (ParameterStyle.QMARK, ParameterStyle.NAMED_COLON)
     default_parameter_style: ParameterStyle = ParameterStyle.QMARK
@@ -102,38 +106,40 @@ class SqliteDriver(
 
     def _execute_statement(
         self, statement: SQL, connection: Optional[SqliteConnection] = None, **kwargs: Any
-    ) -> Union[SelectResultDict, DMLResultDict, ScriptResultDict]:
+    ) -> SQLResult[RowT]:
         if statement.is_script:
-            sql, _ = statement.compile(placeholder_style=ParameterStyle.STATIC)
-            return self._execute_script(sql, connection=connection, **kwargs)
+            sql, _ = self._get_compiled_sql(statement, ParameterStyle.STATIC)
+            return self._execute_script(sql, connection=connection, statement=statement, **kwargs)
+
+        detected_styles = set()
+        sql_str = statement.to_sql(placeholder_style=None)  # Get raw SQL
+        validator = self.config.parameter_validator if self.config else ParameterValidator()
+        param_infos = validator.extract_parameters(sql_str)
+        if param_infos:
+            detected_styles = {p.style for p in param_infos}
 
-        # Determine if we need to convert parameter style
-        detected_styles = {p.style for p in statement.parameter_info}
         target_style = self.default_parameter_style
 
-        # Check if any detected style is not supported
         unsupported_styles = detected_styles - set(self.supported_parameter_styles)
         if unsupported_styles:
-            # Convert to default style if we have unsupported styles
             target_style = self.default_parameter_style
         elif len(detected_styles) > 1:
             # Mixed styles detected - use default style for consistency
             target_style = self.default_parameter_style
         elif detected_styles:
             # Single style detected - use it if supported
-            single_style = next(iter(detected_styles))
-            if single_style in self.supported_parameter_styles:
-                target_style = single_style
+            detected_style = next(iter(detected_styles))
+            if detected_style.value in self.supported_parameter_styles:
+                target_style = detected_style
             else:
                 target_style = self.default_parameter_style
 
         if statement.is_many:
-            sql, params = statement.compile(placeholder_style=target_style)
-            return self._execute_many(sql, params, connection=connection, **kwargs)
+            sql, params = self._get_compiled_sql(statement, target_style)
+            return self._execute_many(sql, params, connection=connection, statement=statement, **kwargs)
 
-        sql, params = statement.compile(placeholder_style=target_style)
+        sql, params = self._get_compiled_sql(statement, target_style)
 
-        # Process parameters through type coercion
         params = self._process_parameters(params)
 
         # SQLite expects tuples for positional parameters
@@ -144,58 +150,127 @@ class SqliteDriver(
 
     def _execute(
         self, sql: str, parameters: Any, statement: SQL, connection: Optional[SqliteConnection] = None, **kwargs: Any
-    ) -> Union[SelectResultDict, DMLResultDict]:
+    ) -> SQLResult[RowT]:
         """Execute a single statement with parameters."""
-        conn = self._connection(connection)
-        with self._get_cursor(conn) as cursor:
-            # SQLite expects tuple or dict parameters
-            if parameters is not None and not isinstance(parameters, (tuple, list, dict)):
-                # Convert scalar to tuple
-                parameters = (parameters,)
-            cursor.execute(sql, parameters or ())
+        # Use provided connection or driver's default connection
+        conn = connection if connection is not None else self._connection(None)
+        with managed_transaction_sync(conn, auto_commit=True) as txn_conn, self._get_cursor(txn_conn) as cursor:
+            # Convert parameters using consolidated utility
+            converted_params_list = convert_parameter_sequence(parameters)
+            params_for_execute: Any
+            if converted_params_list and len(converted_params_list) == 1:
+                # Single parameter should be tuple for SQLite
+                if not isinstance(converted_params_list[0], (tuple, list, dict)):
+                    params_for_execute = (converted_params_list[0],)
+                else:
+                    params_for_execute = converted_params_list[0]
+            else:
+                # Multiple parameters
+                params_for_execute = tuple(converted_params_list) if converted_params_list else ()
+
+            cursor.execute(sql, params_for_execute)
             if self.returns_rows(statement.expression):
                 fetched_data: list[sqlite3.Row] = cursor.fetchall()
-                return {
-                    "data": fetched_data,
-                    "column_names": [col[0] for col in cursor.description or []],
-                    "rows_affected": len(fetched_data),
-                }
-            return {"rows_affected": cursor.rowcount, "status_message": "OK"}
+                return SQLResult(
+                    statement=statement,
+                    data=cast("list[RowT]", fetched_data),
+                    column_names=[col[0] for col in cursor.description or []],
+                    rows_affected=len(fetched_data),
+                    operation_type="SELECT",
+                )
+            operation_type = self._determine_operation_type(statement)
+
+            return SQLResult(
+                statement=statement,
+                data=[],
+                rows_affected=cursor.rowcount,
+                operation_type=operation_type,
+                metadata={"status_message": "OK"},
+            )
 
     def _execute_many(
-        self, sql: str, param_list: Any, connection: Optional[SqliteConnection] = None, **kwargs: Any
-    ) -> DMLResultDict:
+        self,
+        sql: str,
+        param_list: Any,
+        connection: Optional[SqliteConnection] = None,
+        statement: Optional[SQL] = None,
+        **kwargs: Any,
+    ) -> SQLResult[RowT]:
         """Execute a statement many times with a list of parameter tuples."""
-        conn = self._connection(connection)
-        if param_list:
-            param_list = self._process_parameters(param_list)
+        # Use provided connection or driver's default connection
+        conn = connection if connection is not None else self._connection(None)
+        with managed_transaction_sync(conn, auto_commit=True) as txn_conn:
+            # Normalize parameter list using consolidated utility
+            converted_param_list = convert_parameter_sequence(param_list)
+            formatted_params: list[tuple[Any, ...]] = []
+            if converted_param_list:
+                for param_set in converted_param_list:
+                    if isinstance(param_set, (list, tuple)):
+                        formatted_params.append(tuple(param_set))
+                    elif param_set is None:
+                        formatted_params.append(())
+                    else:
+                        formatted_params.append((param_set,))
 
-        # Convert parameter list to proper format for executemany
-        formatted_params: list[tuple[Any, ...]] = []
-        if param_list and isinstance(param_list, list):
-            for param_set in cast("list[Union[list, tuple]]", param_list):
-                if isinstance(param_set, (list, tuple)):
-                    formatted_params.append(tuple(param_set))
-                elif param_set is None:
-                    formatted_params.append(())
-                else:
-                    formatted_params.append((param_set,))
+            with self._get_cursor(txn_conn) as cursor:
+                cursor.executemany(sql, formatted_params)
 
-        with self._get_cursor(conn) as cursor:
-            cursor.executemany(sql, formatted_params)
-            return {"rows_affected": cursor.rowcount, "status_message": "OK"}
+                if statement is None:
+                    statement = SQL(sql, _dialect=self.dialect)
+
+                return SQLResult(
+                    statement=statement,
+                    data=[],
+                    rows_affected=cursor.rowcount,
+                    operation_type="EXECUTE",
+                    metadata={"status_message": "OK"},
+                )
 
     def _execute_script(
-        self, script: str, connection: Optional[SqliteConnection] = None, **kwargs: Any
-    ) -> ScriptResultDict:
-        """Execute a script on the SQLite connection."""
-        conn = self._connection(connection)
+        self, script: str, connection: Optional[SqliteConnection] = None, statement: Optional[SQL] = None, **kwargs: Any
+    ) -> SQLResult[RowT]:
+        """Execute script using splitter for per-statement validation."""
+        from sqlspec.statement.splitter import split_sql_script
+
+        conn = connection if connection is not None else self._connection(None)
+        statements = split_sql_script(script, dialect="sqlite")
+
+        total_rows = 0
+        successful = 0
+        suppress_warnings = kwargs.get("_suppress_warnings", False)
+
         with self._get_cursor(conn) as cursor:
-            cursor.executescript(script)
-        # executescript doesn't auto-commit in some cases
+            for stmt in statements:
+                try:
+                    # Validate each statement unless warnings suppressed
+                    if not suppress_warnings and statement:
+                        # Run validation through pipeline
+                        temp_sql = SQL(stmt, config=statement._config)
+                        temp_sql._ensure_processed()
+                        # Validation errors are logged as warnings by default
+
+                    cursor.execute(stmt)
+                    successful += 1
+                    total_rows += cursor.rowcount or 0
+                except Exception as e:  # noqa: PERF203
+                    if not kwargs.get("continue_on_error", False):
+                        raise
+                    logger.warning("Script statement failed: %s", e)
+
         conn.commit()
-        result: ScriptResultDict = {"statements_executed": -1, "status_message": "SCRIPT EXECUTED"}
-        return result
+
+        if statement is None:
+            statement = SQL(script, _dialect=self.dialect).as_script()
+
+        return SQLResult(
+            statement=statement,
+            data=[],
+            rows_affected=total_rows,
+            operation_type="SCRIPT",
+            total_statements=len(statements),
+            successful_statements=successful,
+            metadata={"status_message": "SCRIPT EXECUTED"},
+        )
 
     def _ingest_arrow_table(self, table: Any, table_name: str, mode: str = "create", **options: Any) -> int:
         """SQLite-specific Arrow table ingestion using CSV conversion.
@@ -208,12 +283,10 @@ class SqliteDriver(
 
         import pyarrow.csv as pa_csv
 
-        # Convert Arrow table to CSV in memory
         csv_buffer = io.BytesIO()
         pa_csv.write_csv(table, csv_buffer)
         csv_content = csv_buffer.getvalue()
 
-        # Create a temporary file path
         temp_filename = f"sqlspec_temp_{table_name}_{id(self)}.csv"
         temp_path = Path(tempfile.gettempdir()) / temp_filename
 
@@ -258,46 +331,3 @@ class SqliteDriver(
             data_iter = list(reader)  # Read all data into memory
             cursor.executemany(sql, data_iter)
             return cursor.rowcount
-
-    def _wrap_select_result(
-        self, statement: SQL, result: SelectResultDict, schema_type: Optional[type[ModelDTOT]] = None, **kwargs: Any
-    ) -> Union[SQLResult[ModelDTOT], SQLResult[RowT]]:
-        rows_as_dicts = [dict(row) for row in result["data"]]
-        if schema_type:
-            return SQLResult[ModelDTOT](
-                statement=statement,
-                data=list(self.to_schema(data=rows_as_dicts, schema_type=schema_type)),
-                column_names=result["column_names"],
-                rows_affected=result["rows_affected"],
-                operation_type="SELECT",
-            )
-
-        return SQLResult[RowT](
-            statement=statement,
-            data=rows_as_dicts,
-            column_names=result["column_names"],
-            rows_affected=result["rows_affected"],
-            operation_type="SELECT",
-        )
-
-    def _wrap_execute_result(
-        self, statement: SQL, result: Union[DMLResultDict, ScriptResultDict], **kwargs: Any
-    ) -> SQLResult[RowT]:
-        if is_dict_with_field(result, "statements_executed"):
-            return SQLResult[RowT](
-                statement=statement,
-                data=[],
-                rows_affected=0,
-                operation_type="SCRIPT",
-                metadata={
-                    "status_message": result.get("status_message", ""),
-                    "statements_executed": result.get("statements_executed", -1),
-                },
-            )
-        return SQLResult[RowT](
-            statement=statement,
-            data=[],
-            rows_affected=cast("int", result.get("rows_affected", -1)),
-            operation_type=statement.expression.key.upper() if statement.expression else "UNKNOWN",
-            metadata={"status_message": result.get("status_message", "")},
-        )
