@@ -1,16 +1,22 @@
 """Driver mixins for instrumentation, storage, and utilities."""
 
+from sqlspec.driver.mixins._cache import AsyncAdapterCacheMixin, SyncAdapterCacheMixin
 from sqlspec.driver.mixins._pipeline import AsyncPipelinedExecutionMixin, SyncPipelinedExecutionMixin
+from sqlspec.driver.mixins._query_tools import AsyncQueryMixin, SyncQueryMixin
 from sqlspec.driver.mixins._result_utils import ToSchemaMixin
 from sqlspec.driver.mixins._sql_translator import SQLTranslatorMixin
 from sqlspec.driver.mixins._storage import AsyncStorageMixin, SyncStorageMixin
 from sqlspec.driver.mixins._type_coercion import TypeCoercionMixin
 
 __all__ = (
+    "AsyncAdapterCacheMixin",
     "AsyncPipelinedExecutionMixin",
+    "AsyncQueryMixin",
     "AsyncStorageMixin",
     "SQLTranslatorMixin",
+    "SyncAdapterCacheMixin",
     "SyncPipelinedExecutionMixin",
+    "SyncQueryMixin",
     "SyncStorageMixin",
     "ToSchemaMixin",
     "TypeCoercionMixin",
