@@ -2,6 +2,7 @@
 
 from abc import ABC, abstractmethod
 from collections import abc
+from collections.abc import Sequence
 from dataclasses import dataclass
 from datetime import datetime
 from typing import TYPE_CHECKING, Any, Generic, Literal, Optional, Protocol, Union, runtime_checkable
@@ -17,6 +18,7 @@ if TYPE_CHECKING:
 __all__ = (
     "AnyCollectionFilter",
     "BeforeAfterFilter",
+    "FilterTypeT",
     "FilterTypes",
     "InAnyFilter",
     "InCollectionFilter",
@@ -24,6 +26,7 @@ __all__ = (
     "NotAnyCollectionFilter",
     "NotInCollectionFilter",
     "NotInSearchFilter",
+    "OffsetPagination",
     "OnBeforeAfterFilter",
     "OrderByFilter",
     "PaginationFilter",
@@ -112,9 +115,7 @@ class BeforeAfterFilter(StatementFilter):
             final_condition = conditions[0]
             for cond in conditions[1:]:
                 final_condition = exp.And(this=final_condition, expression=cond)
-            # Use the SQL object's where method which handles all cases
             result = statement.where(final_condition)
-            # Add the filter's parameters to the result
             _, named_params = self.extract_parameters()
             for name, value in named_params.items():
                 result = result.add_named_parameter(name, value)
@@ -171,7 +172,6 @@ class OnBeforeAfterFilter(StatementFilter):
             for cond in conditions[1:]:
                 final_condition = exp.And(this=final_condition, expression=cond)
             result = statement.where(final_condition)
-            # Add the filter's parameters to the result
             _, named_params = self.extract_parameters()
             for name, value in named_params.items():
                 result = result.add_named_parameter(name, value)
@@ -229,7 +229,6 @@ class InCollectionFilter(InAnyFilter[T]):
         ]
 
         result = statement.where(exp.In(this=exp.column(self.field_name), expressions=placeholder_expressions))
-        # Add the filter's parameters to the result
         _, named_params = self.extract_parameters()
         for name, value in named_params.items():
             result = result.add_named_parameter(name, value)
@@ -273,7 +272,6 @@ class NotInCollectionFilter(InAnyFilter[T]):
         result = statement.where(
             exp.Not(this=exp.In(this=exp.column(self.field_name), expressions=placeholder_expressions))
         )
-        # Add the filter's parameters to the result
         _, named_params = self.extract_parameters()
         for name, value in named_params.items():
             result = result.add_named_parameter(name, value)
@@ -323,7 +321,6 @@ class AnyCollectionFilter(InAnyFilter[T]):
         array_expr = exp.Array(expressions=placeholder_expressions)
         # Generates SQL like: self.field_name = ANY(ARRAY[?, ?, ...])
         result = statement.where(exp.EQ(this=exp.column(self.field_name), expression=exp.Any(this=array_expr)))
-        # Add the filter's parameters to the result
         _, named_params = self.extract_parameters()
         for name, value in named_params.items():
             result = result.add_named_parameter(name, value)
@@ -372,7 +369,6 @@ class NotAnyCollectionFilter(InAnyFilter[T]):
         # Generates SQL like: NOT (self.field_name = ANY(ARRAY[?, ?, ...]))
         condition = exp.EQ(this=exp.column(self.field_name), expression=exp.Any(this=array_expr))
         result = statement.where(exp.Not(this=condition))
-        # Add the filter's parameters to the result
         _, named_params = self.extract_parameters()
         for name, value in named_params.items():
             result = result.add_named_parameter(name, value)
@@ -396,13 +392,47 @@ class LimitOffsetFilter(PaginationFilter):
     offset: int
     """Value for ``OFFSET`` clause of query."""
 
+    def __post_init__(self) -> None:
+        """Initialize parameter names."""
+        # Generate unique parameter names to avoid conflicts
+        import uuid
+
+        unique_suffix = str(uuid.uuid4()).replace("-", "")[:8]
+        self._limit_param_name = f"limit_{unique_suffix}"
+        self._offset_param_name = f"offset_{unique_suffix}"
+
     def extract_parameters(self) -> tuple[list[Any], dict[str, Any]]:
         """Extract filter parameters."""
-        # Return the limit and offset values as named parameters
-        return [], {"limit": self.limit, "offset": self.offset}
+        return [], {self._limit_param_name: self.limit, self._offset_param_name: self.offset}
 
     def append_to_statement(self, statement: "SQL") -> "SQL":
-        return statement.limit(self.limit, use_parameter=True).offset(self.offset, use_parameter=True)
+        # Create limit and offset expressions using our pre-generated parameter names
+        from sqlglot import exp
+
+        limit_placeholder = exp.Placeholder(this=self._limit_param_name)
+        offset_placeholder = exp.Placeholder(this=self._offset_param_name)
+
+        # Apply LIMIT and OFFSET to the statement
+        result = statement
+
+        # Check if the statement supports LIMIT directly
+        if isinstance(result._statement, exp.Select):
+            new_statement = result._statement.limit(limit_placeholder)
+        else:
+            # Wrap in a SELECT if the statement doesn't support LIMIT directly
+            new_statement = exp.Select().from_(result._statement).limit(limit_placeholder)
+
+        # Add OFFSET
+        if isinstance(new_statement, exp.Select):
+            new_statement = new_statement.offset(offset_placeholder)
+
+        result = result.copy(statement=new_statement)
+
+        # Add the parameters to the result
+        _, named_params = self.extract_parameters()
+        for name, value in named_params.items():
+            result = result.add_named_parameter(name, value)
+        return result.filter(self)
 
 
 @dataclass
@@ -420,12 +450,21 @@ class OrderByFilter(StatementFilter):
         return [], {}
 
     def append_to_statement(self, statement: "SQL") -> "SQL":
-        normalized_sort_order = self.sort_order.lower()
-        if normalized_sort_order not in {"asc", "desc"}:
-            normalized_sort_order = "asc"
-        if normalized_sort_order == "desc":
-            return statement.order_by(exp.column(self.field_name).desc())
-        return statement.order_by(exp.column(self.field_name).asc())
+        converted_sort_order = self.sort_order.lower()
+        if converted_sort_order not in {"asc", "desc"}:
+            converted_sort_order = "asc"
+
+        col_expr = exp.column(self.field_name)
+        order_expr = col_expr.desc() if converted_sort_order == "desc" else col_expr.asc()
+
+        # Check if the statement supports ORDER BY directly
+        if isinstance(statement._statement, exp.Select):
+            new_statement = statement._statement.order_by(order_expr)
+        else:
+            # Wrap in a SELECT if the statement doesn't support ORDER BY directly
+            new_statement = exp.Select().from_(statement._statement).order_by(order_expr)
+
+        return statement.copy(statement=new_statement)
 
 
 @dataclass
@@ -450,7 +489,6 @@ class SearchFilter(StatementFilter):
             if isinstance(self.field_name, str):
                 self._param_name = f"{self.field_name}_search"
             else:
-                # For multiple fields, use a generic search parameter name
                 self._param_name = "search_value"
 
     def extract_parameters(self) -> tuple[list[Any], dict[str, Any]]:
@@ -484,7 +522,6 @@ class SearchFilter(StatementFilter):
                     final_condition = exp.Or(this=final_condition, expression=cond)
             result = statement.where(final_condition)
 
-        # Add the filter's parameters to the result
         _, named_params = self.extract_parameters()
         for name, value in named_params.items():
             result = result.add_named_parameter(name, value)
@@ -502,7 +539,6 @@ class NotInSearchFilter(SearchFilter):
             if isinstance(self.field_name, str):
                 self._param_name = f"{self.field_name}_not_search"
             else:
-                # For multiple fields, use a generic search parameter name
                 self._param_name = "not_search_value"
 
     def extract_parameters(self) -> tuple[list[Any], dict[str, Any]]:
@@ -536,13 +572,31 @@ class NotInSearchFilter(SearchFilter):
                     final_condition = exp.And(this=final_condition, expression=cond)
             result = statement.where(final_condition)
 
-        # Add the filter's parameters to the result
         _, named_params = self.extract_parameters()
         for name, value in named_params.items():
             result = result.add_named_parameter(name, value)
         return result
 
 
+@dataclass
+class OffsetPagination(Generic[T]):
+    """Container for data returned using limit/offset pagination."""
+
+    __slots__ = ("items", "limit", "offset", "total")
+
+    items: Sequence[T]
+    """List of data being sent as part of the response."""
+    limit: int
+    """Maximal number of items to send."""
+    offset: int
+    """Offset from the beginning of the query.
+
+    Identical to an index.
+    """
+    total: int
+    """Total number of items."""
+
+
 def apply_filter(statement: "SQL", filter_obj: StatementFilter) -> "SQL":
     """Apply a statement filter to a SQL query object.
 
