@@ -29,45 +29,53 @@ def psycopg_session(postgres_service: PostgresService) -> Generator[PsycopgSyncD
         password=postgres_service.password,
         dbname=postgres_service.database,
         autocommit=True,  # Enable autocommit for tests
-        statement_config=SQLConfig(enable_transformations=False, enable_normalization=False, enable_parsing=False),
+        statement_config=SQLConfig(enable_transformations=False, enable_validation=False, enable_parsing=False),
     )
 
-    with config.provide_session() as session:
-        # Create test table
-        session.execute_script("""
-            CREATE TABLE IF NOT EXISTS test_table (
-                id SERIAL PRIMARY KEY,
-                name TEXT NOT NULL,
-                value INTEGER DEFAULT 0,
-                created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
-            )
-        """)
-        yield session
-        # Cleanup - handle potential transaction errors
-        try:
-            session.execute_script("DROP TABLE IF EXISTS test_table")
-        except Exception:
-            # If the transaction is in an error state, rollback first
-            if hasattr(session.connection, "rollback"):
-                session.connection.rollback()
-            # Try again after rollback
+    try:
+        with config.provide_session() as session:
+            # Create test table
+            session.execute_script("""
+                CREATE TABLE IF NOT EXISTS test_table (
+                    id SERIAL PRIMARY KEY,
+                    name TEXT NOT NULL,
+                    value INTEGER DEFAULT 0,
+                    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP
+                )
+            """)
+            yield session
+            # Cleanup - handle potential transaction errors
             try:
                 session.execute_script("DROP TABLE IF EXISTS test_table")
             except Exception:
-                # If it still fails, ignore - table might not exist
-                pass
+                # If the transaction is in an error state, rollback first
+                if hasattr(session.connection, "rollback"):
+                    session.connection.rollback()
+                # Try again after rollback
+                try:
+                    session.execute_script("DROP TABLE IF EXISTS test_table")
+                except Exception:
+                    # If it still fails, ignore - table might not exist
+                    pass
+    finally:
+        # Ensure pool is closed properly to avoid "cannot join current thread" warnings
+        if config.pool_instance:
+            config.pool_instance.close(timeout=5.0)
+            config.pool_instance = None
 
 
 @pytest.mark.xdist_group("postgres")
 def test_psycopg_basic_crud(psycopg_session: PsycopgSyncDriver) -> None:
     """Test basic CRUD operations."""
     # INSERT
-    insert_result = psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("test_name", 42))
+    insert_result = psycopg_session.execute(
+        "INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("test_name", 42)
+    )
     assert isinstance(insert_result, SQLResult)
     assert insert_result.rows_affected == 1
 
     # SELECT
-    select_result = psycopg_session.execute("SELECT name, value FROM test_table WHERE name = %s", ("test_name",))
+    select_result = psycopg_session.execute("SELECT name, value FROM test_table WHERE name = %s", ("test_name"))
     assert isinstance(select_result, SQLResult)
     assert select_result.data is not None
     assert len(select_result.data) == 1
@@ -80,13 +88,13 @@ def test_psycopg_basic_crud(psycopg_session: PsycopgSyncDriver) -> None:
     assert update_result.rows_affected == 1
 
     # Verify UPDATE
-    verify_result = psycopg_session.execute("SELECT value FROM test_table WHERE name = %s", ("test_name",))
+    verify_result = psycopg_session.execute("SELECT value FROM test_table WHERE name = %s", ("test_name"))
     assert isinstance(verify_result, SQLResult)
     assert verify_result.data is not None
     assert verify_result.data[0]["value"] == 100
 
     # DELETE
-    delete_result = psycopg_session.execute("DELETE FROM test_table WHERE name = %s", ("test_name",))
+    delete_result = psycopg_session.execute("DELETE FROM test_table WHERE name = %s", ("test_name"))
     assert isinstance(delete_result, SQLResult)
     assert delete_result.rows_affected == 1
 
@@ -108,7 +116,7 @@ def test_psycopg_basic_crud(psycopg_session: PsycopgSyncDriver) -> None:
 def test_psycopg_parameter_styles(psycopg_session: PsycopgSyncDriver, params: Any, style: ParamStyle) -> None:
     """Test different parameter binding styles."""
     # Insert test data
-    psycopg_session.execute("INSERT INTO test_table (name) VALUES (%s)", ("test_value",))
+    psycopg_session.execute("INSERT INTO test_table (name) VALUES (%s)", "test_value")
 
     # Test parameter style
     if style == "tuple_binds":
@@ -128,7 +136,9 @@ def test_psycopg_execute_many(psycopg_session: PsycopgSyncDriver) -> None:
     """Test execute_many functionality."""
     params_list = [("name1", 1), ("name2", 2), ("name3", 3)]
 
-    result = psycopg_session.execute_many("INSERT INTO test_table (name, value) VALUES (%s, %s)", params_list)
+    result = psycopg_session.execute_many(
+        "INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=params_list
+    )
     assert isinstance(result, SQLResult)
     assert result.rows_affected == len(params_list)
 
@@ -179,7 +189,8 @@ def test_psycopg_result_methods(psycopg_session: PsycopgSyncDriver) -> None:
     """Test SelectResult and ExecuteResult methods."""
     # Insert test data
     psycopg_session.execute_many(
-        "INSERT INTO test_table (name, value) VALUES (%s, %s)", [("result1", 10), ("result2", 20), ("result3", 30)]
+        "INSERT INTO test_table (name, value) VALUES (%s, %s)",
+        parameters=[("result1", 10), ("result2", 20), ("result3", 30)],
     )
 
     # Test SelectResult methods
@@ -198,7 +209,7 @@ def test_psycopg_result_methods(psycopg_session: PsycopgSyncDriver) -> None:
     assert not result.is_empty()
 
     # Test empty result
-    empty_result = psycopg_session.execute("SELECT * FROM test_table WHERE name = %s", ("nonexistent",))
+    empty_result = psycopg_session.execute("SELECT * FROM test_table WHERE name = %s", ("nonexistent"))
     assert isinstance(empty_result, SQLResult)
     assert empty_result.is_empty()
     assert empty_result.get_first() is None
@@ -212,7 +223,7 @@ def test_psycopg_error_handling(psycopg_session: PsycopgSyncDriver) -> None:
         psycopg_session.execute("INVALID SQL STATEMENT")
 
     # Test constraint violation
-    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("unique_test", 1))
+    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("unique_test", 1))
 
     # Try to insert with invalid column reference
     with pytest.raises(Exception):  # psycopg.errors.UndefinedColumn
@@ -248,7 +259,7 @@ def test_psycopg_data_types(psycopg_session: PsycopgSyncDriver) -> None:
             %s, %s, %s, %s, %s, %s, %s, %s, %s
         )
     """,
-        (
+        parameters=(
             "text_value",
             42,
             123.45,
@@ -283,10 +294,12 @@ def test_psycopg_data_types(psycopg_session: PsycopgSyncDriver) -> None:
 def test_psycopg_transactions(psycopg_session: PsycopgSyncDriver) -> None:
     """Test transaction behavior."""
     # PostgreSQL supports explicit transactions
-    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("transaction_test", 100))
+    psycopg_session.execute(
+        "INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("transaction_test", 100)
+    )
 
     # Verify data is committed
-    result = psycopg_session.execute("SELECT COUNT(*) as count FROM test_table WHERE name = %s", ("transaction_test",))
+    result = psycopg_session.execute("SELECT COUNT(*) as count FROM test_table WHERE name = %s", ("transaction_test"))
     assert isinstance(result, SQLResult)
     assert result.data is not None
     assert result.data[0]["count"] == 1
@@ -298,7 +311,7 @@ def test_psycopg_complex_queries(psycopg_session: PsycopgSyncDriver) -> None:
     # Insert test data
     test_data = [("Alice", 25), ("Bob", 30), ("Charlie", 35), ("Diana", 28)]
 
-    psycopg_session.execute_many("INSERT INTO test_table (name, value) VALUES (%s, %s)", test_data)
+    psycopg_session.execute_many("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=test_data)
 
     # Test JOIN (self-join)
     join_result = psycopg_session.execute("""
@@ -356,7 +369,9 @@ def test_psycopg_schema_operations(psycopg_session: PsycopgSyncDriver) -> None:
     """)
 
     # Insert data into new table
-    insert_result = psycopg_session.execute("INSERT INTO schema_test (description) VALUES (%s)", ("test description",))
+    insert_result = psycopg_session.execute(
+        "INSERT INTO schema_test (description) VALUES (%s)", parameters=("test description",)
+    )
     assert isinstance(insert_result, SQLResult)
     assert insert_result.rows_affected == 1
 
@@ -379,7 +394,7 @@ def test_psycopg_schema_operations(psycopg_session: PsycopgSyncDriver) -> None:
 def test_psycopg_column_names_and_metadata(psycopg_session: PsycopgSyncDriver) -> None:
     """Test column names and result metadata."""
     # Insert test data
-    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("metadata_test", 123))
+    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("metadata_test", 123))
 
     # Test column names
     result = psycopg_session.execute(
@@ -410,11 +425,11 @@ def test_psycopg_with_schema_type(psycopg_session: PsycopgSyncDriver) -> None:
         value: int
 
     # Insert test data
-    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("schema_test", 456))
+    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("schema_test", 456))
 
     # Query with schema type
     result = psycopg_session.execute(
-        "SELECT id, name, value FROM test_table WHERE name = %s", ("schema_test",), schema_type=TestRecord
+        "SELECT id, name, value FROM test_table WHERE name = %s", "schema_test", schema_type=TestRecord
     )
 
     assert isinstance(result, SQLResult)
@@ -432,7 +447,7 @@ def test_psycopg_performance_bulk_operations(psycopg_session: PsycopgSyncDriver)
     bulk_data = [(f"bulk_user_{i}", i * 10) for i in range(100)]
 
     # Bulk insert
-    result = psycopg_session.execute_many("INSERT INTO test_table (name, value) VALUES (%s, %s)", bulk_data)
+    result = psycopg_session.execute_many("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=bulk_data)
     assert isinstance(result, SQLResult)
     assert result.rows_affected == 100
 
@@ -457,7 +472,7 @@ def test_psycopg_postgresql_specific_features(psycopg_session: PsycopgSyncDriver
     """Test PostgreSQL-specific features with psycopg."""
     # Test RETURNING clause
     returning_result = psycopg_session.execute(
-        "INSERT INTO test_table (name, value) VALUES (%s, %s) RETURNING id, name", ("returning_test", 999)
+        "INSERT INTO test_table (name, value) VALUES (%s, %s) RETURNING id, name", parameters=("returning_test", 999)
     )
     assert isinstance(returning_result, SQLResult)  # psycopg returns SQLResult for RETURNING
     assert returning_result.data is not None
@@ -466,7 +481,8 @@ def test_psycopg_postgresql_specific_features(psycopg_session: PsycopgSyncDriver
 
     # Test window functions
     psycopg_session.execute_many(
-        "INSERT INTO test_table (name, value) VALUES (%s, %s)", [("window1", 10), ("window2", 20), ("window3", 30)]
+        "INSERT INTO test_table (name, value) VALUES (%s, %s)",
+        parameters=[("window1", 10), ("window2", 20), ("window3", 30)],
     )
 
     window_result = psycopg_session.execute("""
@@ -499,7 +515,7 @@ def test_psycopg_json_operations(psycopg_session: PsycopgSyncDriver) -> None:
 
     # Insert JSON data
     json_data = '{"name": "test", "age": 30, "tags": ["postgres", "json"]}'
-    psycopg_session.execute("INSERT INTO json_test (data) VALUES (%s)", (json_data,))
+    psycopg_session.execute("INSERT INTO json_test (data) VALUES (%s)", parameters=(json_data,))
 
     # Test JSON queries
     json_result = psycopg_session.execute("SELECT data->>'name' as name, data->>'age' as age FROM json_test")
@@ -513,52 +529,117 @@ def test_psycopg_json_operations(psycopg_session: PsycopgSyncDriver) -> None:
 
 
 @pytest.mark.xdist_group("postgres")
-def test_psycopg_copy_operations(psycopg_session: PsycopgSyncDriver) -> None:
-    """Test PostgreSQL COPY operations with psycopg.
+def test_psycopg_copy_operations_positional(psycopg_session: PsycopgSyncDriver) -> None:
+    """Test PostgreSQL COPY operations with psycopg using positional parameters."""
+    # Create temp table for copy test
+    psycopg_session.execute_script("""
+        DROP TABLE IF EXISTS copy_test_pos;
+        CREATE TABLE copy_test_pos (
+            id INTEGER,
+            name TEXT,
+            value INTEGER
+        )
+    """)
 
-    The SQLSpec psycopg driver implements special handling for COPY commands
-    using cursor.copy() method to support this functionality.
-    """
-    # Test basic COPY functionality if available
-    try:
-        # Create temp table for copy test
-        psycopg_session.execute_script("""
-            CREATE TABLE copy_test (
-                id INTEGER,
-                name TEXT,
-                value INTEGER
-            )
-        """)
+    # Test COPY FROM STDIN with text format using positional parameter
+    copy_data = "1\ttest1\t100\n2\ttest2\t200\n"
+    result = psycopg_session.execute("COPY copy_test_pos FROM STDIN WITH (FORMAT text)", copy_data)
+    assert isinstance(result, SQLResult)
+    assert result.rows_affected >= 0  # May be -1 or actual count
 
-        # Test if COPY is supported (depends on psycopg implementation)
-        copy_data = "1\ttest1\t100\n2\ttest2\t200\n"
+    # Verify data was copied
+    verify_result = psycopg_session.execute("SELECT * FROM copy_test_pos ORDER BY id")
+    assert isinstance(verify_result, SQLResult)
+    assert verify_result.data is not None
+    assert len(verify_result.data) == 2
+    assert verify_result.data[0]["name"] == "test1"
+    assert verify_result.data[1]["value"] == 200
 
-        # Try COPY FROM if supported
-        try:
-            psycopg_session.execute("COPY copy_test FROM STDIN WITH (FORMAT text)", copy_data)
+    # Clean up
+    psycopg_session.execute_script("DROP TABLE copy_test_pos")
 
-            # Verify data was copied
-            verify_result = psycopg_session.execute("SELECT COUNT(*) as count FROM copy_test")
-            assert isinstance(verify_result, SQLResult)
-            assert verify_result.data[0]["count"] == 2
 
-        except Exception:
-            # COPY might not be supported in this implementation
-            pass
+@pytest.mark.xdist_group("postgres")
+def test_psycopg_copy_operations_keyword(psycopg_session: PsycopgSyncDriver) -> None:
+    """Test PostgreSQL COPY operations with psycopg using keyword parameters."""
+    # Create temp table for copy test
+    psycopg_session.execute_script("""
+        DROP TABLE IF EXISTS copy_test_kw;
+        CREATE TABLE copy_test_kw (
+            id INTEGER,
+            name TEXT,
+            value INTEGER
+        )
+    """)
 
-        # Clean up
-        psycopg_session.execute_script("DROP TABLE copy_test")
+    # Test COPY FROM STDIN with text format using keyword parameter
+    copy_data = "3\ttest3\t300\n4\ttest4\t400\n"
+    result = psycopg_session.execute("COPY copy_test_kw FROM STDIN WITH (FORMAT text)", parameters=copy_data)
+    assert isinstance(result, SQLResult)
+    assert result.rows_affected >= 0  # May be -1 or actual count
 
-    except Exception:
-        # COPY operations might not be supported
-        pytest.skip("COPY operations not supported in this psycopg implementation")
+    # Verify data was copied
+    verify_result = psycopg_session.execute("SELECT * FROM copy_test_kw ORDER BY id")
+    assert isinstance(verify_result, SQLResult)
+    assert verify_result.data is not None
+    assert len(verify_result.data) == 2
+    assert verify_result.data[0]["name"] == "test3"
+    assert verify_result.data[1]["value"] == 400
+
+    # Clean up
+    psycopg_session.execute_script("DROP TABLE copy_test_kw")
+
+
+@pytest.mark.xdist_group("postgres")
+def test_psycopg_copy_csv_format(psycopg_session: PsycopgSyncDriver) -> None:
+    """Test PostgreSQL COPY operations with CSV format."""
+    # Create temp table
+    psycopg_session.execute_script("""
+        DROP TABLE IF EXISTS copy_csv_sync;
+        CREATE TABLE copy_csv_sync (
+            id INTEGER,
+            name TEXT,
+            value INTEGER
+        )
+    """)
+
+    # Test COPY FROM STDIN with CSV format - positional
+    csv_data = "5,test5,500\n6,test6,600\n7,test7,700\n"
+    result_pos = psycopg_session.execute("COPY copy_csv_sync FROM STDIN WITH (FORMAT csv)", csv_data)
+    assert isinstance(result_pos, SQLResult)
+    assert result_pos.rows_affected == 3
+
+    # Verify data
+    verify_result = psycopg_session.execute("SELECT * FROM copy_csv_sync ORDER BY id")
+    assert isinstance(verify_result, SQLResult)
+    assert len(verify_result.data) == 3
+    assert verify_result.data[0]["name"] == "test5"
+    assert verify_result.data[2]["value"] == 700
+
+    # Clear table and test with keyword parameter
+    psycopg_session.execute_script("TRUNCATE TABLE copy_csv_sync")
+
+    csv_data2 = "8,test8,800\n9,test9,900\n"
+    result_kw = psycopg_session.execute("COPY copy_csv_sync FROM STDIN WITH (FORMAT csv)", parameters=csv_data2)
+    assert isinstance(result_kw, SQLResult)
+    assert result_kw.rows_affected == 2
+
+    # Verify data again
+    verify_result2 = psycopg_session.execute("SELECT * FROM copy_csv_sync ORDER BY id")
+    assert isinstance(verify_result2, SQLResult)
+    assert len(verify_result2.data) == 2
+    assert verify_result2.data[0]["name"] == "test8"
+    assert verify_result2.data[1]["value"] == 900
+
+    # Clean up
+    psycopg_session.execute_script("DROP TABLE copy_csv_sync")
 
 
 @pytest.mark.xdist_group("postgres")
 def test_psycopg_fetch_arrow_table(psycopg_session: PsycopgSyncDriver) -> None:
     """Integration test: fetch_arrow_table returns ArrowResult with correct pyarrow.Table."""
-    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("arrow1", 111))
-    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("arrow2", 222))
+    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("arrow1", 111))
+    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("arrow2", 222))
     statement = SQL("SELECT name, value FROM test_table ORDER BY name")
     result = psycopg_session.fetch_arrow_table(statement)
     assert isinstance(result, ArrowResult)
@@ -572,8 +653,8 @@ def test_psycopg_fetch_arrow_table(psycopg_session: PsycopgSyncDriver) -> None:
 def test_psycopg_to_parquet(psycopg_session: PsycopgSyncDriver) -> None:
     """Integration test: to_parquet writes correct data to a Parquet file."""
     # Insert fresh data for this test
-    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("pq1", 123))
-    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", ("pq2", 456))
+    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("pq1", 123))
+    psycopg_session.execute("INSERT INTO test_table (name, value) VALUES (%s, %s)", parameters=("pq2", 456))
 
     # First verify data can be selected normally
     normal_result = psycopg_session.execute("SELECT name, value FROM test_table ORDER BY name")
