@@ -43,7 +43,7 @@ def test_sqlite_basic_crud(sqlite_session: SqliteDriver) -> None:
     assert insert_result.rows_affected == 1
 
     # SELECT
-    select_result = sqlite_session.execute("SELECT name, value FROM test_table WHERE name = ?", ("test_name",))
+    select_result = sqlite_session.execute("SELECT name, value FROM test_table WHERE name = ?", ("test_name"))
     assert isinstance(select_result, SQLResult)
     assert select_result.data is not None
     assert len(select_result.data) == 1
@@ -56,13 +56,13 @@ def test_sqlite_basic_crud(sqlite_session: SqliteDriver) -> None:
     assert update_result.rows_affected == 1
 
     # Verify UPDATE
-    verify_result = sqlite_session.execute("SELECT value FROM test_table WHERE name = ?", ("test_name",))
+    verify_result = sqlite_session.execute("SELECT value FROM test_table WHERE name = ?", ("test_name"))
     assert isinstance(verify_result, SQLResult)
     assert verify_result.data is not None
     assert verify_result.data[0]["value"] == 100
 
     # DELETE
-    delete_result = sqlite_session.execute("DELETE FROM test_table WHERE name = ?", ("test_name",))
+    delete_result = sqlite_session.execute("DELETE FROM test_table WHERE name = ?", ("test_name"))
     assert isinstance(delete_result, SQLResult)
     assert delete_result.rows_affected == 1
 
@@ -76,7 +76,7 @@ def test_sqlite_basic_crud(sqlite_session: SqliteDriver) -> None:
 @pytest.mark.parametrize(
     ("params", "style"),
     [
-        pytest.param(("test_value",), "tuple_binds", id="tuple_binds"),
+        pytest.param(("test_value"), "tuple_binds", id="tuple_binds"),
         pytest.param({"name": "test_value"}, "dict_binds", id="dict_binds"),
     ],
 )
@@ -84,7 +84,7 @@ def test_sqlite_basic_crud(sqlite_session: SqliteDriver) -> None:
 def test_sqlite_parameter_styles(sqlite_session: SqliteDriver, params: Any, style: ParamStyle) -> None:
     """Test different parameter binding styles."""
     # Insert test data
-    sqlite_session.execute("INSERT INTO test_table (name) VALUES (?)", ("test_value",))
+    sqlite_session.execute("INSERT INTO test_table (name) VALUES (?)", ("test_value"))
 
     # Test parameter style
     if style == "tuple_binds":
@@ -183,7 +183,7 @@ def test_sqlite_result_methods(sqlite_session: SqliteDriver) -> None:
     assert not result.is_empty()
 
     # Test empty result
-    empty_result = sqlite_session.execute("SELECT * FROM test_table WHERE name = ?", ("nonexistent",))
+    empty_result = sqlite_session.execute("SELECT * FROM test_table WHERE name = ?", ("nonexistent"))
     assert isinstance(empty_result, SQLResult)
     assert empty_result.is_empty()
     assert empty_result.get_first() is None
@@ -253,7 +253,7 @@ def test_sqlite_transactions(sqlite_session: SqliteDriver) -> None:
     sqlite_session.execute("INSERT INTO test_table (name, value) VALUES (?, ?)", ("transaction_test", 100))
 
     # Verify data is committed
-    result = sqlite_session.execute("SELECT COUNT(*) as count FROM test_table WHERE name = ?", ("transaction_test",))
+    result = sqlite_session.execute("SELECT COUNT(*) as count FROM test_table WHERE name = ?", ("transaction_test"))
     assert isinstance(result, SQLResult)
     assert result.data is not None
     assert result.data[0]["count"] == 1
@@ -325,7 +325,7 @@ def test_sqlite_schema_operations(sqlite_session: SqliteDriver) -> None:
     assert create_result.operation_type == "SCRIPT"
 
     # Insert data into new table
-    insert_result = sqlite_session.execute("INSERT INTO schema_test (description) VALUES (?)", ("test description",))
+    insert_result = sqlite_session.execute("INSERT INTO schema_test (description) VALUES (?)", ("test description"))
     assert isinstance(insert_result, SQLResult)
     assert insert_result.rows_affected == 1
 
@@ -349,7 +349,7 @@ def test_sqlite_column_names_and_metadata(sqlite_session: SqliteDriver) -> None:
 
     # Test column names
     result = sqlite_session.execute(
-        "SELECT id, name, value, created_at FROM test_table WHERE name = ?", ("metadata_test",)
+        "SELECT id, name, value, created_at FROM test_table WHERE name = ?", ("metadata_test")
     )
     assert isinstance(result, SQLResult)
     assert result.column_names == ["id", "name", "value", "created_at"]
@@ -381,7 +381,7 @@ def test_sqlite_with_schema_type(sqlite_session: SqliteDriver) -> None:
 
     # Query with schema type
     result = sqlite_session.execute(
-        "SELECT id, name, value FROM test_table WHERE name = ?", ("schema_test",), schema_type=TestRecord
+        "SELECT id, name, value FROM test_table WHERE name = ?", ("schema_test"), schema_type=TestRecord
     )
 
     assert isinstance(result, SQLResult)
