@@ -587,7 +587,14 @@ def test_sql_loader_with_complex_parameter_types(complex_sql_files: Path) -> Non
 
     assert isinstance(analytics_sql, SQL)
     assert analytics_sql.parameters["start_period"] == "2024-01-01 00:00:00"
-    assert analytics_sql.parameters["category_filter"] is None
+    # TypedParameter wraps None values with type information
+    from sqlspec.statement.parameters import TypedParameter
+
+    category_filter = analytics_sql.parameters["category_filter"]
+    if isinstance(category_filter, TypedParameter):
+        assert category_filter.value is None
+    else:
+        assert category_filter is None
     assert analytics_sql.parameters["min_revenue_threshold"] == 500.00
 
 
