@@ -1,7 +1,7 @@
 """Unit tests for ADBC driver."""
 
 import tempfile
-from typing import Any, cast
+from typing import Any
 from unittest.mock import Mock
 
 import pyarrow as pa
@@ -13,7 +13,7 @@ from sqlspec.adapters.adbc.driver import AdbcDriver
 from sqlspec.exceptions import RepositoryError
 from sqlspec.statement.builder import QueryBuilder
 from sqlspec.statement.parameters import ParameterStyle
-from sqlspec.statement.result import ArrowResult, SelectResultDict, SQLResult
+from sqlspec.statement.result import ArrowResult, SQLResult
 from sqlspec.statement.sql import SQL, SQLConfig
 from sqlspec.typing import DictRow
 
@@ -30,7 +30,7 @@ def mock_adbc_connection() -> Mock:
 def mock_cursor() -> Mock:
     """Create a mock ADBC cursor."""
     mock_cursor = Mock(spec=Cursor)
-    mock_cursor.description = [(col,) for col in ["id", "name", "email"]]
+    mock_cursor.description = ["id", "name", "email"]
     mock_cursor.rowcount = 1
     mock_cursor.fetchall.return_value = [(1, "John Doe", "john@example.com"), (2, "Jane Smith", "jane@example.com")]
     return mock_cursor
@@ -39,7 +39,7 @@ def mock_cursor() -> Mock:
 @pytest.fixture
 def adbc_driver(mock_adbc_connection: Mock) -> AdbcDriver:
     """Create an ADBC driver with mock connection."""
-    return AdbcDriver(connection=mock_adbc_connection, config=SQLConfig(strict_mode=False))
+    return AdbcDriver(connection=mock_adbc_connection, config=SQLConfig())
 
 
 def test_adbc_driver_initialization(mock_adbc_connection: Mock) -> None:
@@ -56,11 +56,13 @@ def test_adbc_driver_initialization(mock_adbc_connection: Mock) -> None:
 
 def test_adbc_driver_initialization_with_config(mock_adbc_connection: Mock) -> None:
     """Test AdbcDriver initialization with custom configuration."""
-    config = SQLConfig(strict_mode=False)
+    config = SQLConfig()
 
     driver = AdbcDriver(connection=mock_adbc_connection, config=config)
 
-    assert driver.config == config
+    # The driver updates the config to include the dialect
+    assert driver.config.parse_errors_as_warnings == config.parse_errors_as_warnings
+    assert driver.config.dialect == "postgres"  # Added by driver
 
 
 def test_adbc_driver_get_dialect_postgresql() -> None:
@@ -237,17 +239,15 @@ def test_adbc_driver_execute_statement_select(adbc_driver: AdbcDriver, mock_curs
     mock_cursor.fetchall.return_value = [(1, "John Doe", "john@example.com")]
     mock_cursor.description = [("id",), ("name",), ("email",)]
 
-    statement = SQL("SELECT * FROM users WHERE id = ?", parameters=[123])
-    result = cast("SelectResultDict", adbc_driver._execute_statement(statement))
+    # Use PostgreSQL-style placeholders since the mock connection is PostgreSQL
+    statement = SQL("SELECT * FROM users WHERE id = $1", parameters=[123])
+    result = adbc_driver._execute_statement(statement)
 
-    assert isinstance(result, dict)
-    assert "data" in result
-    assert "column_names" in result
-    assert "rows_affected" in result
-
-    assert len(result["data"]) == 1
-    assert result["column_names"] == ["id", "name", "email"]
-    assert result["rows_affected"] == 1
+    assert isinstance(result, SQLResult)
+    assert len(result.data) == 1
+    assert result.column_names == ["id", "name", "email"]
+    assert result.rows_affected == 1
+    assert result.operation_type == "SELECT"
 
     # Verify execute and fetchall were called
     mock_cursor.execute.assert_called_once_with("SELECT * FROM users WHERE id = $1", [123])
@@ -390,15 +390,14 @@ def test_adbc_driver_instrumentation_logging(mock_adbc_connection: Mock, mock_cu
 
     mock_adbc_connection.cursor.return_value = mock_cursor
     mock_cursor.fetchall.return_value = [(1, "John")]
-    mock_cursor.description = [(col,) for col in ["id", "name", "email"]]
+    mock_cursor.description = ["id", "name", "email"]
 
     statement = SQL("SELECT * FROM users WHERE id = $1", parameters=[123])
     # Parameters argument removed from _execute_statement call
-    cursor_result = driver._execute_statement(statement)
-    assert isinstance(cursor_result, dict) and "data" in cursor_result  # Type narrowing
-    select_result = driver._wrap_select_result(statement, cast("SelectResultDict", cursor_result))
+    result = driver._execute_statement(statement)
 
-    assert isinstance(select_result, SQLResult)
+    assert isinstance(result, SQLResult)
+    assert result.operation_type == "SELECT"
     # Logging calls are verified through the instrumentation config
 
 
@@ -438,7 +437,7 @@ def test_adbc_driver_build_statement_method(adbc_driver: AdbcDriver) -> None:
 
     sql_config = SQLConfig()
     # Test with SQL statement
-    sql_stmt = SQL("SELECT * FROM users", _config=sql_config)
+    sql_stmt = SQL("SELECT * FROM users", config=sql_config)
     result = adbc_driver._build_statement(sql_stmt, _config=sql_config)
     assert isinstance(result, SQL)
     assert result.sql == sql_stmt.sql
@@ -455,15 +454,15 @@ def test_adbc_driver_build_statement_method(adbc_driver: AdbcDriver) -> None:
     built_stmt_from_string = adbc_driver._build_statement(string_sql, _config=sql_config)
     assert isinstance(built_stmt_from_string, SQL)
     assert built_stmt_from_string.sql == string_sql
-    assert built_stmt_from_string.parameters is None
+    assert built_stmt_from_string.parameters == {}
 
     # Test with plain string SQL and parameters
     string_sql_with_params = "SELECT id FROM yet_another_table WHERE id = ?"
-    params_for_string = (1,)
+    params_for_string = 1  # Pass as individual parameter, not tuple
     built_stmt_with_params = adbc_driver._build_statement(string_sql_with_params, params_for_string, _config=sql_config)
     assert isinstance(built_stmt_with_params, SQL)
     assert built_stmt_with_params.sql == string_sql_with_params
-    assert built_stmt_with_params.parameters == [1]  # Tuple params are unpacked into list
+    assert built_stmt_with_params.parameters == (1,)  # Parameters wrapped as tuple by SQL constructor
 
 
 def test_adbc_driver_fetch_arrow_table_native(adbc_driver: AdbcDriver, mock_cursor: Mock) -> None:
