@@ -66,7 +66,7 @@ async def test_aiosqlite_config_provide_session() -> None:
         assert isinstance(session, AiosqliteDriver)
         # Check that parameter styles were set
         assert session.config.allowed_parameter_styles == ("qmark", "named_colon")
-        assert session.config.target_parameter_style == "qmark"
+        assert session.config.default_parameter_style == "qmark"
 
 
 def test_aiosqlite_config_driver_type() -> None:
