@@ -11,14 +11,13 @@ This module tests the AsyncpgDriver class including:
 """
 
 from decimal import Decimal
-from typing import Any, cast
+from typing import Any
 from unittest.mock import AsyncMock, MagicMock, patch
 
 import pytest
 
 from sqlspec.adapters.asyncpg import AsyncpgDriver
 from sqlspec.statement.parameters import ParameterStyle
-from sqlspec.statement.result import SelectResultDict, SQLResult
 from sqlspec.statement.sql import SQL, SQLConfig
 from sqlspec.typing import DictRow
 
@@ -193,7 +192,7 @@ async def test_execute_statement_routing(
 
     # Create config that allows DDL if needed
     config = SQLConfig(enable_validation=False) if "CREATE" in sql_text else SQLConfig()
-    statement = SQL(sql_text, _config=config)
+    statement = SQL(sql_text, config=config)
     statement._is_script = is_script
     statement._is_many = is_many
 
@@ -212,15 +211,16 @@ async def test_execute_select_statement(driver: AsyncpgDriver, mock_connection:
     mock_record.__iter__ = MagicMock(return_value=iter([("id", 1), ("name", "test"), ("email", "test@example.com")]))
     mock_dict = {"id": 1, "name": "test", "email": "test@example.com"}
 
-    # Mock the dict() constructor to return our expected dict
-    with patch("builtins.dict", return_value=mock_dict):
-        mock_connection.fetch.return_value = [mock_record, mock_record]
+    # Mock the connection to return pre-converted dictionaries
+    mock_connection.fetch.return_value = [mock_dict, mock_dict]
 
-        statement = SQL("SELECT * FROM users")
-        result = await driver._execute_statement(statement)
+    statement = SQL("SELECT * FROM users")
+    result = await driver._execute_statement(statement)
 
-        # Now expect the converted dictionary data
-        assert result == {"data": [mock_dict, mock_dict], "column_names": ["id", "name", "email"], "rows_affected": 2}
+    # Now expect the converted dictionary data
+    assert result.data == [mock_dict, mock_dict]
+    assert result.column_names == ["id", "name", "email"]
+    assert result.rows_affected == 2
 
     mock_connection.fetch.assert_called_once_with("SELECT * FROM users")
 
@@ -233,7 +233,8 @@ async def test_execute_dml_statement(driver: AsyncpgDriver, mock_connection: Asy
     statement = SQL("INSERT INTO users (name, email) VALUES ($1, $2)", ["Alice", "alice@example.com"])
     result = await driver._execute_statement(statement)
 
-    assert result == {"rows_affected": 1, "status_message": "INSERT 0 1"}
+    assert result.rows_affected == 1
+    assert result.metadata["status_message"] == "INSERT 0 1"
 
     mock_connection.execute.assert_called_once_with(
         "INSERT INTO users (name, email) VALUES ($1, $2)", "Alice", "alice@example.com"
@@ -279,7 +280,8 @@ async def test_execute_many(driver: AsyncpgDriver, mock_connection: AsyncMock) -
 
     result = await driver._execute_many(sql, params)
 
-    assert result == {"rows_affected": 3, "status_message": "OK"}
+    assert result.rows_affected == 3
+    assert result.metadata["status_message"] == "OK"
 
     expected_params = [("Alice", "alice@example.com"), ("Bob", "bob@example.com"), ("Charlie", "charlie@example.com")]
     mock_connection.executemany.assert_called_once_with(sql, expected_params)
@@ -319,94 +321,14 @@ async def test_execute_script(driver: AsyncpgDriver, mock_connection: AsyncMock)
 
     result = await driver._execute_script(script)
 
-    assert result == {"statements_executed": -1, "status_message": "CREATE TABLE"}
+    assert result.total_statements == 3  # Now splits and executes each statement
+    assert result.metadata["status_message"] == "CREATE TABLE"
 
-    mock_connection.execute.assert_called_once_with(script)
+    # Now checks that execute was called 3 times (once for each statement)
+    assert mock_connection.execute.call_count == 3
 
 
-# Result Wrapping Tests
-@pytest.mark.asyncio
-async def test_wrap_select_result(driver: AsyncpgDriver) -> None:
-    """Test wrapping SELECT results."""
-    statement = SQL("SELECT * FROM users")
-    result = cast(
-        "SelectResultDict",
-        {
-            "data": [{"id": 1, "name": "Alice"}, {"id": 2, "name": "Bob"}],
-            "column_names": ["id", "name"],
-            "rows_affected": 2,
-        },
-    )
-
-    wrapped: SQLResult[Any] = await driver._wrap_select_result(statement, result)  # type: ignore[arg-type]
-
-    assert isinstance(wrapped, SQLResult)
-    assert wrapped.statement is statement
-    assert len(wrapped.data) == 2
-    assert wrapped.column_names == ["id", "name"]
-    assert wrapped.rows_affected == 2
-    assert wrapped.operation_type == "SELECT"
-
-
-@pytest.mark.asyncio
-async def test_wrap_select_result_with_schema(driver: AsyncpgDriver) -> None:
-    """Test wrapping SELECT results with schema type."""
-    from dataclasses import dataclass
-
-    @dataclass
-    class User:
-        id: int
-        name: str
-
-    statement = SQL("SELECT * FROM users")
-    result = {
-        "data": [{"id": 1, "name": "Alice"}, {"id": 2, "name": "Bob"}],
-        "column_names": ["id", "name"],
-        "rows_affected": 2,
-    }
-
-    wrapped = await driver._wrap_select_result(statement, result, schema_type=User)  # type: ignore[arg-type]
-
-    assert isinstance(wrapped, SQLResult)
-    assert all(isinstance(item, User) for item in wrapped.data)
-    assert wrapped.data[0].id == 1
-    assert wrapped.data[0].name == "Alice"
-
-
-@pytest.mark.asyncio
-async def test_wrap_execute_result_dml(driver: AsyncpgDriver) -> None:
-    """Test wrapping DML results."""
-    statement = SQL("INSERT INTO users VALUES ($1)")
-
-    result = {"rows_affected": 1, "status_message": "INSERT 0 1"}
-
-    wrapped = await driver._wrap_execute_result(statement, result)  # type: ignore[arg-type]
-
-    assert isinstance(wrapped, SQLResult)
-    assert wrapped.data == []
-    assert wrapped.rows_affected == 1
-    assert wrapped.operation_type == "INSERT"
-    assert wrapped.metadata["status_message"] == "INSERT 0 1"
-
-
-@pytest.mark.asyncio
-async def test_wrap_execute_result_script(driver: AsyncpgDriver) -> None:
-    """Test wrapping script results."""
-    from sqlspec.statement.sql import SQLConfig
-
-    config = SQLConfig(enable_validation=False)  # Allow DDL
-    statement = SQL("CREATE TABLE test; INSERT INTO test;", _config=config)
-
-    result = {"statements_executed": -1, "status_message": "CREATE TABLE"}
-
-    wrapped = await driver._wrap_execute_result(statement, result)  # type: ignore[arg-type]
-
-    assert isinstance(wrapped, SQLResult)
-    assert wrapped.data == []
-    assert wrapped.rows_affected == 0
-    assert wrapped.operation_type == "SCRIPT"
-    assert wrapped.metadata["status_message"] == "CREATE TABLE"
-    assert wrapped.metadata["statements_executed"] == -1
+# Note: Result wrapping tests removed - drivers now return SQLResult directly from execute methods
 
 
 # Parameter Processing Tests
@@ -506,7 +428,7 @@ async def test_execute_with_no_parameters(driver: AsyncpgDriver, mock_connection
     from sqlspec.statement.sql import SQLConfig
 
     config = SQLConfig(enable_validation=False)  # Allow DDL
-    statement = SQL("CREATE TABLE test (id INTEGER)", _config=config)
+    statement = SQL("CREATE TABLE test (id INTEGER)", config=config)
     await driver._execute_statement(statement)
 
     # sqlglot normalizes INTEGER to INT
@@ -521,7 +443,9 @@ async def test_execute_select_with_empty_result(driver: AsyncpgDriver, mock_conn
     statement = SQL("SELECT * FROM users WHERE 1=0")
     result = await driver._execute_statement(statement)
 
-    assert result == {"data": [], "column_names": [], "rows_affected": 0}
+    assert result.data == []
+    assert result.column_names == []
+    assert result.rows_affected == 0
 
 
 @pytest.mark.asyncio
