@@ -24,18 +24,14 @@ from typing import TYPE_CHECKING, Any, Optional, Union, cast
 from unittest.mock import Mock
 
 import pytest
-from sqlglot import exp
+from sqlglot import Expression, exp
 
 from sqlspec.exceptions import SQLBuilderError
-from sqlspec.statement.builder.mixins._aggregate_functions import AggregateFunctionsMixin
-from sqlspec.statement.builder.mixins._from import FromClauseMixin
-from sqlspec.statement.builder.mixins._group_by import GroupByClauseMixin
-from sqlspec.statement.builder.mixins._having import HavingClauseMixin
-from sqlspec.statement.builder.mixins._insert_from_select import InsertFromSelectMixin
-from sqlspec.statement.builder.mixins._insert_values import InsertValuesMixin
-from sqlspec.statement.builder.mixins._join import JoinClauseMixin
-from sqlspec.statement.builder.mixins._limit_offset import LimitOffsetClauseMixin
-from sqlspec.statement.builder.mixins._merge_clauses import (
+from sqlspec.statement.builder import Column, FunctionColumn
+from sqlspec.statement.builder.mixins._cte_and_set_ops import SetOperationMixin
+from sqlspec.statement.builder.mixins._insert_operations import InsertFromSelectMixin, InsertValuesMixin
+from sqlspec.statement.builder.mixins._join_operations import JoinClauseMixin
+from sqlspec.statement.builder.mixins._merge_operations import (
     MergeIntoClauseMixin,
     MergeMatchedClauseMixin,
     MergeNotMatchedBySourceClauseMixin,
@@ -43,19 +39,50 @@ from sqlspec.statement.builder.mixins._merge_clauses import (
     MergeOnClauseMixin,
     MergeUsingClauseMixin,
 )
-from sqlspec.statement.builder.mixins._order_by import OrderByClauseMixin
-from sqlspec.statement.builder.mixins._pivot import PivotClauseMixin
-from sqlspec.statement.builder.mixins._returning import ReturningClauseMixin
-from sqlspec.statement.builder.mixins._set_ops import SetOperationMixin
-from sqlspec.statement.builder.mixins._unpivot import UnpivotClauseMixin
-from sqlspec.statement.builder.mixins._update_from import UpdateFromClauseMixin
-from sqlspec.statement.builder.mixins._update_set import UpdateSetClauseMixin
-from sqlspec.statement.builder.mixins._where import WhereClauseMixin
+from sqlspec.statement.builder.mixins._order_limit_operations import (
+    LimitOffsetClauseMixin,
+    OrderByClauseMixin,
+    ReturningClauseMixin,
+)
+from sqlspec.statement.builder.mixins._pivot_operations import PivotClauseMixin, UnpivotClauseMixin
+from sqlspec.statement.builder.mixins._select_operations import SelectClauseMixin
+from sqlspec.statement.builder.mixins._update_operations import UpdateFromClauseMixin, UpdateSetClauseMixin
+from sqlspec.statement.builder.mixins._where_clause import HavingClauseMixin, WhereClauseMixin
 
 if TYPE_CHECKING:
     from sqlglot.dialects.dialect import DialectType
 
 
+def create_mock_query_builder() -> Any:
+    """Create a mock query builder that implements SQLBuilderProtocol."""
+    from unittest.mock import Mock
+
+    # Create a mock that implements the SQLBuilderProtocol properly
+    class MockQueryBuilder:
+        def __init__(self) -> None:
+            self._parameters: dict[str, Any] = {}
+            self._parameter_counter: int = 0
+            self.dialect: Optional[Any] = None
+            self.dialect_name: Optional[str] = None
+            self._expression: Optional[Any] = None
+
+        @property
+        def parameters(self) -> dict[str, Any]:
+            return self._parameters
+
+        def build(self) -> Any:
+            return Mock(sql="SELECT id FROM users")
+
+        def add_parameter(self, value: Any) -> tuple[Any, str]:
+            return (self, "param_1")
+
+        def _parameterize_expression(self, expr: Any) -> Any:
+            return Mock()
+
+    # Return an instance of the mock query builder
+    return MockQueryBuilder()
+
+
 # Helper Classes
 class MockQueryResult:
     """Mock query result for testing."""
@@ -123,7 +150,7 @@ def test_where_clause_basic(condition: Any, expected_type: type[exp.Expression])
 def test_where_clause_wrong_expression_type() -> None:
     """Test WHERE clause with wrong expression type."""
     builder = WhereTestBuilder(exp.Insert())
-    with pytest.raises(SQLBuilderError, match="Cannot add WHERE clause to unsupported expression type"):
+    with pytest.raises(SQLBuilderError, match="WHERE clause not supported for Insert"):
         builder.where("id = 1")
 
 
@@ -181,7 +208,7 @@ def test_where_null_checks(column: Any) -> None:
     [
         ([1, 2, 3], exp.Tuple),
         ((4, 5, 6), exp.Tuple),
-        (Mock(build=lambda: Mock(sql="SELECT id FROM users")), type(None)),  # Subquery
+        (create_mock_query_builder(), type(None)),  # Subquery
     ],
     ids=["list_values", "tuple_values", "subquery"],
 )
@@ -339,7 +366,7 @@ def test_order_by_wrong_expression_type() -> None:
         builder.order_by("name")
 
 
-class FromTestBuilder(MockBuilder, FromClauseMixin):
+class FromTestBuilder(MockBuilder, SelectClauseMixin):
     """Test builder with FROM clause mixin."""
 
     pass
@@ -513,7 +540,7 @@ def test_set_operation_wrong_expression_type() -> None:
         builder1.union(builder2)
 
 
-class GroupByTestBuilder(MockBuilder, GroupByClauseMixin):
+class GroupByTestBuilder(MockBuilder, SelectClauseMixin):
     """Test builder with GROUP BY mixin."""
 
     pass
@@ -914,19 +941,19 @@ def test_unpivot_wrong_expression_type() -> None:
         builder.unpivot(value_column_name="value", name_column_name="name", columns_to_unpivot=["col1"])
 
 
-class AggregateTestBuilder(MockBuilder, AggregateFunctionsMixin):
+class AggregateTestBuilder(MockBuilder, SelectClauseMixin):  # pyright: ignore
     """Test builder with aggregate functions mixin."""
 
-    def select(self, expr: Any) -> "AggregateTestBuilder":
+    def select(self, *columns: Union[str, Expression, Column, FunctionColumn]) -> "AggregateTestBuilder":
         """Mock select method to add expressions."""
         if self._expression is None:
             self._expression = exp.Select()
 
         exprs = self._expression.args.get("expressions")
         if exprs is None:
-            self._expression.set("expressions", [expr])
+            self._expression.set("expressions", [*columns])
         else:
-            exprs.append(expr)
+            exprs.extend(columns)
         return self
 
 
@@ -935,52 +962,13 @@ class AggregateTestBuilder(MockBuilder, AggregateFunctionsMixin):
     "method,column,expected_function",
     [
         ("count_", "*", "COUNT"),
-        pytest.param(
-            "count_distinct", "user_id", "COUNT", marks=pytest.mark.skip(reason="count_distinct not implemented")
-        ),
         ("sum_", "amount", "SUM"),
         ("avg_", "score", "AVG"),
         ("min_", "price", "MIN"),
         ("max_", "price", "MAX"),
-        pytest.param("stddev", "value", "STDDEV", marks=pytest.mark.skip(reason="stddev not implemented")),
-        pytest.param("stddev_pop", "value", "STDDEV_POP", marks=pytest.mark.skip(reason="stddev_pop not implemented")),
-        pytest.param(
-            "stddev_samp", "value", "STDDEV_SAMP", marks=pytest.mark.skip(reason="stddev_samp not implemented")
-        ),
-        pytest.param("variance", "value", "VARIANCE", marks=pytest.mark.skip(reason="variance not implemented")),
-        pytest.param("var_pop", "value", "VAR_POP", marks=pytest.mark.skip(reason="var_pop not implemented")),
-        pytest.param("var_samp", "value", "VAR_SAMP", marks=pytest.mark.skip(reason="var_samp not implemented")),
         ("array_agg", "tags", "ARRAY_AGG"),
-        pytest.param("string_agg", "name", "STRING_AGG", marks=pytest.mark.skip(reason="string_agg not implemented")),
-        pytest.param("json_agg", "data", "JSON_AGG", marks=pytest.mark.skip(reason="json_agg not implemented")),
-        pytest.param("jsonb_agg", "data", "JSONB_AGG", marks=pytest.mark.skip(reason="jsonb_agg not implemented")),
-        ("bool_and", "active", "BOOL_AND"),
-        ("bool_or", "verified", "BOOL_OR"),
-        pytest.param("bit_and", "flags", "BIT_AND", marks=pytest.mark.skip(reason="bit_and not implemented")),
-        pytest.param("bit_or", "flags", "BIT_OR", marks=pytest.mark.skip(reason="bit_or not implemented")),
-    ],
-    ids=[
-        "count",
-        "count_distinct",
-        "sum",
-        "avg",
-        "min",
-        "max",
-        "stddev",
-        "stddev_pop",
-        "stddev_samp",
-        "variance",
-        "var_pop",
-        "var_samp",
-        "array_agg",
-        "string_agg",
-        "json_agg",
-        "jsonb_agg",
-        "bool_and",
-        "bool_or",
-        "bit_and",
-        "bit_or",
     ],
+    ids=["count", "sum", "avg", "min", "max", "array_agg"],
 )
 def test_aggregate_functions(method: str, column: str, expected_function: str) -> None:
     """Test aggregate function methods."""
